@@ -1,4 +1,4 @@
-//@line 41 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/base/content/openLocation.js"
+//@line 41 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/base/content/openLocation.js"
 
 var browser;
 var dialog = {};
@@ -10,6 +10,8 @@ try {
   // not critical, remain silent
 }
 
+Components.utils.import("resource:///modules/openLocationLastURL.jsm");
+
 function onLoad()
 {
   dialog.input         = document.getElementById("dialog.input");
@@ -35,8 +37,7 @@ function onLoad()
       var element = dialog.openWhereList.getElementsByAttribute("value", value)[0];
       if (element)
         dialog.openWhereList.selectedItem = element;
-      dialog.input.value = pref.getComplexValue("general.open_location.last_url",
-                                                Components.interfaces.nsISupportsString).data;
+      dialog.input.value = gOpenLocationLastURL.value;
     }
     catch(ex) {
     }
@@ -81,11 +82,7 @@ function open()
   }
 
   if (pref) {
-    var str = Components.classes["@mozilla.org/supports-string;1"]
-                        .createInstance(Components.interfaces.nsISupportsString);
-    str.data = dialog.input.value;
-    pref.setComplexValue("general.open_location.last_url",
-                         Components.interfaces.nsISupportsString, str);
+    gOpenLocationLastURL.value = dialog.input.value;
     pref.setIntPref("general.open_location.last_window_choice", dialog.openWhereList.value);
   }
 
