@@ -1,12 +1,8 @@
-//@line 42 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 42 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/base/content/pageinfo/pageInfo.js"
 
 //******** define a js object to implement nsITreeView
-function pageInfoTreeView(columnids, copycol)
+function pageInfoTreeView(copycol)
 {
-  // columnids is an array of strings indicating the names of the columns, in order
-  this.columnids = columnids;
-  this.colcount = columnids.length;
-
   // copycol is the index number for the column that we want to add to
   // the copy-n-paste buffer when the user hits accel-c
   this.copycol = copycol;
@@ -31,8 +27,7 @@ pageInfoTreeView.prototype = {
   {
     // row can be null, but js arrays are 0-indexed.
     // colidx cannot be null, but can be larger than the number
-    // of columns in the array (when column is a string not in
-    // this.columnids.) In this case it's the fault of
+    // of columns in the array. In this case it's the fault of
     // whoever typoed while calling this function.
     return this.data[row][column.index] || "";
   },
@@ -50,6 +45,8 @@ pageInfoTreeView.prototype = {
   {
     this.rows = this.data.push(row);
     this.rowCountChanged(this.rows - 1, 1);
+    if (this.selection.count == 0 && this.rowCount && !gImageElement)
+      this.selection.select(0);
   },
 
   rowCountChanged: function(index, count)
@@ -111,6 +108,7 @@ pageInfoTreeView.prototype = {
 // mmm, yummy. global variables.
 var gWindow = null;
 var gDocument = null;
+var gImageElement = null;
 
 // column number to help using the data array
 const COL_IMAGE_ADDRESS = 0;
@@ -127,10 +125,8 @@ const COPYCOL_META_CONTENT = 1;
 const COPYCOL_IMAGE = COL_IMAGE_ADDRESS;
 
 // one nsITreeView for each tree in the window
-var gMetaView = new pageInfoTreeView(["meta-name","meta-content"], COPYCOL_META_CONTENT);
-var gImageView = new pageInfoTreeView(["image-address","image-type","image-size",
-                                       "image-alt","image-count","image-node","image-bg"],
-                                      COPYCOL_IMAGE);
+var gMetaView = new pageInfoTreeView(COPYCOL_META_CONTENT);
+var gImageView = new pageInfoTreeView(COPYCOL_IMAGE);
 
 gImageView.getCellProperties = function(row, col, props) {
   var aserv = Components.classes[ATOM_CONTRACTID]
@@ -148,10 +144,6 @@ var gImageHash = { };
 var gStrings = { };
 var gBundle;
 
-const DRAGSERVICE_CONTRACTID    = "@mozilla.org/widget/dragservice;1";
-const TRANSFERABLE_CONTRACTID   = "@mozilla.org/widget/transferable;1";
-const ARRAY_CONTRACTID          = "@mozilla.org/supports-array;1";
-const STRING_CONTRACTID         = "@mozilla.org/supports-string;1";
 const PERMISSION_CONTRACTID     = "@mozilla.org/permissionmanager;1";
 const PREFERENCES_CONTRACTID    = "@mozilla.org/preferences-service;1";
 const ATOM_CONTRACTID           = "@mozilla.org/atom-service;1";
@@ -222,7 +214,7 @@ var onProcessFrame = [ ];
 var onProcessElement = [ ];
 
 // These functions are called once when all the elements in all of the target
-// document (and all of it's subframes, if any) have been processed
+// document (and all of its subframes, if any) have been processed
 var onFinished = [ ];
 
 // These functions are called once when the Page Info window is closed.
@@ -247,16 +239,12 @@ function onLoadPageInfo()
   gStrings.mediaLink = gBundle.getString("mediaLink");
   gStrings.mediaInput = gBundle.getString("mediaInput");
 
-  if ("arguments" in window && window.arguments.length >= 1 &&
-       window.arguments[0] && window.arguments[0].doc) {
-    gDocument = window.arguments[0].doc;
-    gWindow = gDocument.defaultView;
-  }
-  else {
-    if ("gBrowser" in window.opener)
-      gWindow = window.opener.gBrowser.contentWindow;
-    else
-      gWindow = window.opener.frames[0];
+  var args = "arguments" in window &&
+             window.arguments.length >= 1 &&
+             window.arguments[0];
+
+  if (!args || !args.doc) {
+    gWindow = window.opener.content;
     gDocument = gWindow.document;
   }
 
@@ -264,19 +252,11 @@ function onLoadPageInfo()
   var imageTree = document.getElementById("imagetree");
   imageTree.view = gImageView;
 
-  // build the content
-  loadPageInfo();
-
   /* Select the requested tab, if the name is specified */
-  var initialTab = "generalTab";
-  if ("arguments" in window && window.arguments.length >= 1 &&
-       window.arguments[0] && window.arguments[0].initialTab)
-    initialTab = window.arguments[0].initialTab;
-  var radioGroup = document.getElementById("viewGroup");
-  initialTab = document.getElementById(initialTab) || document.getElementById("generalTab");
-  radioGroup.selectedItem = initialTab;
-  radioGroup.selectedItem.doCommand();
-  radioGroup.focus();
+  loadTab(args);
+  Components.classes["@mozilla.org/observer-service;1"]
+            .getService(Components.interfaces.nsIObserverService)
+            .notifyObservers(window, "page-info-dialog-loaded", null);
 }
 
 function loadPageInfo()
@@ -300,7 +280,7 @@ function loadPageInfo()
   onLoadRegistry.forEach(function(func) { func(); });
 }
 
-function resetPageInfo()
+function resetPageInfo(args)
 {
   /* Reset Meta tags part */
   gMetaView.clear();
@@ -308,9 +288,9 @@ function resetPageInfo()
   /* Reset Media tab */
   var mediaTab = document.getElementById("mediaTab");
   if (!mediaTab.hidden) {
-    var os = Components.classes["@mozilla.org/observer-service;1"]
-                       .getService(Components.interfaces.nsIObserverService);
-    os.removeObserver(imagePermissionObserver, "perm-changed");
+    Components.classes["@mozilla.org/observer-service;1"]
+              .getService(Components.interfaces.nsIObserverService)
+              .removeObserver(imagePermissionObserver, "perm-changed");
     mediaTab.hidden = true;
   }
   gImageView.clear();
@@ -324,16 +304,17 @@ function resetPageInfo()
   /* Call registered overlay reset functions */
   onResetRegistry.forEach(function(func) { func(); });
 
-  /* And let's rebuild the data */
-  loadPageInfo();
+  /* Rebuild the data */
+  loadTab(args);
 }
 
 function onUnloadPageInfo()
 {
+  // Remove the observer, only if there is at least 1 image.
   if (!document.getElementById("mediaTab").hidden) {
-    var os = Components.classes["@mozilla.org/observer-service;1"]
-                       .getService(Components.interfaces.nsIObserverService);
-    os.removeObserver(imagePermissionObserver, "perm-changed");
+    Components.classes["@mozilla.org/observer-service;1"]
+              .getService(Components.interfaces.nsIObserverService)
+              .removeObserver(imagePermissionObserver, "perm-changed");
   }
 
   /* Call registered overlay unload functions */
@@ -362,6 +343,26 @@ function showTab(id)
   deck.selectedPanel = pagel;
 }
 
+function loadTab(args)
+{
+  if (args && args.doc) {
+    gDocument = args.doc;
+    gWindow = gDocument.defaultView;
+  }
+
+  gImageElement = args && args.imageElement;
+
+  /* Load the page info */
+  loadPageInfo();
+
+  var initialTab = (args && args.initialTab) || "generalTab";
+  var radioGroup = document.getElementById("viewGroup");
+  initialTab = document.getElementById(initialTab) || document.getElementById("generalTab");
+  radioGroup.selectedItem = initialTab;
+  radioGroup.selectedItem.doCommand();
+  radioGroup.focus();
+}
+
 function onClickMore()
 {
   var radioGrp = document.getElementById("viewGroup");
@@ -490,6 +491,7 @@ function processFrames()
     var iterator = doc.createTreeWalker(doc, NodeFilter.SHOW_ELEMENT, grabAll, true);
     gFrameList.shift();
     setTimeout(doGrab, 16, iterator);
+    onFinished.push(selectImage);
   }
   else
     onFinished.forEach(function(func) { func(); });
@@ -502,21 +504,15 @@ function doGrab(iterator)
       processFrames();
       return;
     }
-  setTimeout(doGrab, 16, iterator);
-}
 
-function ensureSelection(view)
-{
-  // only select something if nothing is currently selected
-  // and if there's anything to select
-  if (view.selection.count == 0 && view.rowCount)
-    view.selection.select(0);
+  setTimeout(doGrab, 16, iterator);
 }
 
 function addImage(url, type, alt, elem, isBg)
 {
   if (!url)
     return;
+
   if (!gImageHash.hasOwnProperty(url))
     gImageHash[url] = { };
   if (!gImageHash[url].hasOwnProperty(type))
@@ -544,32 +540,39 @@ function addImage(url, type, alt, elem, isBg)
     else
       sizeText = gStrings.unknown;
     gImageView.addRow([url, type, sizeText, alt, 1, elem, isBg]);
+
+    // Add the observer, only once.
     if (gImageView.data.length == 1) {
       document.getElementById("mediaTab").hidden = false;
-      var os = Components.classes["@mozilla.org/observer-service;1"]
-                         .getService(Components.interfaces.nsIObserverService);
-      os.addObserver(imagePermissionObserver, "perm-changed", false);
+      Components.classes["@mozilla.org/observer-service;1"]
+                .getService(Components.interfaces.nsIObserverService)
+                .addObserver(imagePermissionObserver, "perm-changed", false);
     }
   }
   else {
     var i = gImageHash[url][type][alt];
     gImageView.data[i][COL_IMAGE_COUNT]++;
+    if (elem == gImageElement)
+      gImageView.data[i][COL_IMAGE_NODE] = elem;
   }
 }
 
 function grabAll(elem)
 {
-  // check for background images, any node may have one
-  var ComputedStyle = elem.ownerDocument.defaultView.getComputedStyle(elem, "");
-  var url = ComputedStyle && ComputedStyle.getPropertyCSSValue("background-image");
-  if (url && url.primitiveType == CSSPrimitiveValue.CSS_URI)
-    addImage(url.getStringValue(), gStrings.mediaBGImg, gStrings.notSet, elem, true);
+  // check for background images, any node may have multiple
+  var computedStyle = elem.ownerDocument.defaultView.getComputedStyle(elem, "");
+  if (computedStyle) {
+    Array.forEach(computedStyle.getPropertyCSSValue("background-image"), function (url) {
+      if (url.primitiveType == CSSPrimitiveValue.CSS_URI)
+        addImage(url.getStringValue(), gStrings.mediaBGImg, gStrings.notSet, elem, true);
+    });
+  }
 
   // one swi^H^H^Hif-else to rule them all
   if (elem instanceof HTMLImageElement)
     addImage(elem.src, gStrings.mediaImg,
              (elem.hasAttribute("alt")) ? elem.alt : gStrings.notSet, elem, false);
-//@line 613 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 616 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/base/content/pageinfo/pageInfo.js"
   else if (elem instanceof SVGImageElement) {
     try {
       // Note: makeURLAbsolute will throw if either the baseURI is not a valid URI
@@ -578,7 +581,7 @@ function grabAll(elem)
       addImage(href, gStrings.mediaImg, "", elem, false);
     } catch (e) { }
   }
-//@line 622 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 625 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/base/content/pageinfo/pageInfo.js"
   else if (elem instanceof HTMLLinkElement) {
     if (elem.rel && /\bicon\b/i.test(elem.rel))
       addImage(elem.href, gStrings.mediaLink, "", elem, false);
@@ -618,31 +621,16 @@ function onBeginLinkDrag(event,urlField,descField)
   if (row == -1)
     return;
 
-  // Getting drag-system needed services
-  var dragService = Components.classes[DRAGSERVICE_CONTRACTID].getService()
-                              .QueryInterface(Components.interfaces.nsIDragService);
-  var transArray = Components.classes[ARRAY_CONTRACTID]
-                             .createInstance(Components.interfaces.nsISupportsArray);
-  if (!transArray)
-    return;
-  var trans = Components.classes[TRANSFERABLE_CONTRACTID]
-                        .createInstance(Components.interfaces.nsITransferable);
-  if (!trans)
-    return;
-
   // Adding URL flavor
-  trans.addDataFlavor("text/x-moz-url");
   var col = tree.columns[urlField];
   var url = tree.view.getCellText(row, col);
   col = tree.columns[descField];
   var desc = tree.view.getCellText(row, col);
-  var stringURL = Components.classes[STRING_CONTRACTID]
-                            .createInstance(Components.interfaces.nsISupportsString);
-  stringURL.data = url + "\n" + desc;
-  trans.setTransferData("text/x-moz-url", stringURL, stringURL.data.length * 2 );
-  transArray.AppendElement(trans.QueryInterface(Components.interfaces.nsISupports));
 
-  dragService.invokeDragSession(event.target, transArray, null, dragService.DRAGDROP_ACTION_NONE);
+  var dt = event.dataTransfer;
+  dt.setData("text/x-moz-url", url + "\n" + desc);
+  dt.setData("text/url-list", url);
+  dt.setData("text/plain", url);
 }
 
 //******** Image Stuff
@@ -790,9 +778,9 @@ function makePreview(row)
 
   var imageText;
   if (!isBG &&
-//@line 834 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 822 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/base/content/pageinfo/pageInfo.js"
       !(item instanceof SVGImageElement) &&
-//@line 836 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 824 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/base/content/pageinfo/pageInfo.js"
       !(gDocument instanceof ImageDocument)) {
     imageText = item.title || item.alt;
 
@@ -836,7 +824,7 @@ function makePreview(row)
       item instanceof HTMLLinkElement)
     mimeType = item.type;
 
-  if (!mimeType && item instanceof nsIImageLoadingContent) {
+  if (!mimeType && !isBG && item instanceof nsIImageLoadingContent) {
     var imageRequest = item.getRequest(nsIImageLoadingContent.CURRENT_REQUEST);
     if (imageRequest) {
       mimeType = imageRequest.mimeType;
@@ -848,23 +836,28 @@ function makePreview(row)
   if (!mimeType)
     mimeType = getContentTypeFromHeaders(cacheEntryDescriptor);
 
+  var imageType;
   if (mimeType) {
     // We found the type, try to display it nicely
     var imageMimeType = /^image\/(.*)/.exec(mimeType);
     if (imageMimeType) {
-      mimeType = imageMimeType[1].toUpperCase();
+      imageType = imageMimeType[1].toUpperCase();
       if (numFrames > 1)
-        mimeType = gBundle.getFormattedString("mediaAnimatedImageType",
-                                              [mimeType, numFrames]);
+        imageType = gBundle.getFormattedString("mediaAnimatedImageType",
+                                               [imageType, numFrames]);
       else
-        mimeType = gBundle.getFormattedString("mediaImageType", [mimeType]);
+        imageType = gBundle.getFormattedString("mediaImageType", [imageType]);
+    }
+    else {
+      // the MIME type doesn't begin with image/, display the raw type
+      imageType = mimeType;
     }
   }
   else {
     // We couldn't find the type, fall back to the value in the treeview
-    mimeType = gImageView.data[row][COL_IMAGE_TYPE];
+    imageType = gImageView.data[row][COL_IMAGE_TYPE];
   }
-  setItemValue("imagetypetext", mimeType);
+  setItemValue("imagetypetext", imageType);
 
   var imageContainer = document.getElementById("theimagecontainer");
   var oldImage = document.getElementById("thepreviewimage");
@@ -881,9 +874,9 @@ function makePreview(row)
 
   if ((item instanceof HTMLLinkElement || item instanceof HTMLInputElement ||
        item instanceof HTMLImageElement ||
-//@line 925 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 918 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/base/content/pageinfo/pageInfo.js"
        item instanceof SVGImageElement ||
-//@line 927 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 920 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/base/content/pageinfo/pageInfo.js"
       (item instanceof HTMLObjectElement && /^image\//.test(mimeType)) || isBG) && isProtocolAllowed) {
     newImage.setAttribute("src", url);
     physWidth = newImage.width || 0;
@@ -903,12 +896,12 @@ function makePreview(row)
       newImage.height = newImage.naturalHeight;
     }
 
-//@line 947 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 940 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/base/content/pageinfo/pageInfo.js"
     if (item instanceof SVGImageElement) {
       newImage.width = item.width.baseVal.value;
       newImage.height = item.height.baseVal.value;
     }
-//@line 952 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 945 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/base/content/pageinfo/pageInfo.js"
 
     width = newImage.width;
     height = newImage.height;
@@ -977,6 +970,7 @@ var imagePermissionObserver = {
   {
     if (document.getElementById("mediaPreviewBox").collapsed)
       return;
+
     if (aTopic == "perm-changed") {
       var permission = aSubject.QueryInterface(Components.interfaces.nsIPermission);
       if (permission.type == "image") {
@@ -1079,7 +1073,7 @@ function formatNumber(number)
 
 function formatDate(datestr, unknown)
 {
-  // scriptable date formater, for pretty printing dates
+  // scriptable date formatter, for pretty printing dates
   var dateService = Components.classes["@mozilla.org/intl/scriptabledateformat;1"]
                               .getService(Components.interfaces.nsIScriptableDateFormat);
 
@@ -1131,3 +1125,19 @@ function doSelectAll()
   if (elem && "treeBoxObject" in elem)
     elem.view.selection.selectAll();
 }
+
+function selectImage() {
+  if (!gImageElement)
+    return;
+
+  var tree = document.getElementById("imagetree");
+  for (var i = 0; i < tree.view.rowCount; i++) {
+    if (gImageElement == gImageView.data[i][COL_IMAGE_NODE] &&
+        !gImageView.data[i][COL_IMAGE_BG]) {
+      tree.view.selection.select(i);
+      tree.treeBoxObject.ensureRowIsVisible(i);
+      tree.focus();
+      return;
+    }
+  }
+}
