@@ -24,6 +24,7 @@
  *   Asaf Romano <mano@mozilla.com>
  *   Sungjoon Steve Won <stevewon@gmail.com>
  *   Dietrich Ayala <dietrich@mozilla.com>
+ *   Marco Bonardo <mak77@bonardo.net>
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -61,12 +62,13 @@ const LMANNO_FEEDURI = "livemark/feedURI";
 const LMANNO_SITEURI = "livemark/siteURI";
 const ORGANIZER_FOLDER_ANNO = "PlacesOrganizer/OrganizerFolder";
 const ORGANIZER_QUERY_ANNO = "PlacesOrganizer/OrganizerQuery";
-const ORGANIZER_LEFTPANE_VERSION = 4;
+const ORGANIZER_LEFTPANE_VERSION = 6;
+const EXCLUDE_FROM_BACKUP_ANNO = "places/excludeFromBackup";
 
-//@line 71 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/places/content/utils.js"
+//@line 73 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/places/content/utils.js"
 // On other platforms, the transferable system converts "\r\n" to "\n".
 const NEWLINE = "\r\n";
-//@line 74 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/places/content/utils.js"
+//@line 76 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/places/content/utils.js"
 
 function QI_node(aNode, aIID) {
   return aNode.QueryInterface(aIID);
@@ -123,6 +125,12 @@ var PlacesUIUtils = {
                                                 Ci.nsIPrefLocalizedString).data;
   },
 
+  get privateBrowsing() {
+    delete this.privateBrowsing;
+    return this.privateBrowsing = Cc["@mozilla.org/privatebrowsing;1"].
+                                  getService(Ci.nsIPrivateBrowsingService);
+  },
+
   /**
    * Makes a URI from a spec, and do fixup
    * @param   aSpec
@@ -279,7 +287,7 @@ var PlacesUIUtils = {
     }
 
     // tag folders use tag transactions
-    if (aContainer == PlacesUtils.bookmarks.tagsFolder) {
+    if (aContainer == PlacesUtils.tagsFolderId) {
       var txns = [];
       if (aData.children) {
         aData.children.forEach(function(aChild) {
@@ -352,37 +360,34 @@ var PlacesUIUtils = {
       case PlacesUtils.TYPE_X_MOZ_PLACE_CONTAINER:
         if (copy)
           return this._getFolderCopyTransaction(data, container, index);
-        else { // Move the item
-          var id = data.folder ? data.folder.id : data.id;
-          return this.ptm.moveItem(id, container, index);
-        }
+        // Otherwise move the item.
+        return this.ptm.moveItem(data.id, container, index);
         break;
       case PlacesUtils.TYPE_X_MOZ_PLACE:
-        if (data.id <= 0) // non-bookmark item
+        if (data.id == -1) // Not bookmarked.
           return this._getURIItemCopyTransaction(data, container, index);
   
-        if (copy) {
-          // Copying a child of a live-bookmark by itself should result
-          // as a new normal bookmark item (bug 376731)
-          return this._getBookmarkItemCopyTransaction(data, container, index,
-                                                      ["livemark/bookmarkFeedURI"]);
-        }
-        else
-          return this.ptm.moveItem(data.id, container, index);
+        if (copy)
+          return this._getBookmarkItemCopyTransaction(data, container, index);
+        // Otherwise move the item.
+        return this.ptm.moveItem(data.id, container, index);
         break;
       case PlacesUtils.TYPE_X_MOZ_PLACE_SEPARATOR:
         // There is no data in a separator, so copying it just amounts to
         // inserting a new separator.
         if (copy)
           return this.ptm.createSeparator(container, index);
-        // Move the separator otherwise
+        // Otherwise move the item.
         return this.ptm.moveItem(data.id, container, index);
         break;
       default:
-        if (type == PlacesUtils.TYPE_X_MOZ_URL || type == PlacesUtils.TYPE_UNICODE) {
-          var title = (type == PlacesUtils.TYPE_X_MOZ_URL) ? data.title : data.uri;
-          return this.ptm.createItem(PlacesUtils._uri(data.uri), container, index,
-                                     title);
+        if (type == PlacesUtils.TYPE_X_MOZ_URL ||
+            type == PlacesUtils.TYPE_UNICODE ||
+            type == TAB_DROP_TYPE) {
+          var title = (type != PlacesUtils.TYPE_UNICODE) ? data.title :
+                                                             data.uri;
+          return this.ptm.createItem(PlacesUtils._uri(data.uri),
+                                     container, index, title);
         }
     }
     return null;
@@ -459,7 +464,7 @@ var PlacesUIUtils = {
     if (aDefaultInsertionPoint) {
       info.defaultInsertionPoint = aDefaultInsertionPoint;
       if (!aShowPicker)
-        info.hiddenRows = ["folder picker"];
+        info.hiddenRows = ["folderPicker"];
     }
 
     if (aLoadInSidebar)
@@ -495,7 +500,7 @@ var PlacesUIUtils = {
     var info = {
       action: "add",
       type: "bookmark",
-      hiddenRows: ["location", "description", "loadInSidebar"]
+      hiddenRows: ["description"]
     };
     if (aURI)
       info.uri = aURI;
@@ -510,14 +515,19 @@ var PlacesUIUtils = {
     if (aDefaultInsertionPoint) {
       info.defaultInsertionPoint = aDefaultInsertionPoint;
       if (!aShowPicker)
-        info.hiddenRows.push("folder picker");
+        info.hiddenRows.push("folderPicker");
     }
 
     if (aLoadInSidebar)
       info.loadBookmarkInSidebar = true;
+    else
+      info.hiddenRows = info.hiddenRows.concat(["location", "loadInSidebar"]);
 
     if (typeof(aKeyword) == "string") {
       info.keyword = aKeyword;
+      // Hide the Tags field if we are adding a keyword.
+      info.hiddenRows.push("tags");
+      // Keyword related params.
       if (typeof(aPostData) == "string")
         info.postData = aPostData;
       if (typeof(aCharSet) == "string")
@@ -577,7 +587,7 @@ var PlacesUIUtils = {
     if (aDefaultInsertionPoint) {
       info.defaultInsertionPoint = aDefaultInsertionPoint;
       if (!aShowPicker)
-        info.hiddenRows = ["folder picker"];
+        info.hiddenRows = ["folderPicker"];
     }
     return this._showBookmarkDialog(info);
   },
@@ -597,7 +607,7 @@ var PlacesUIUtils = {
     var info = {
       action: "add",
       type: "livemark",
-      hiddenRows: ["feedURI", "siteURI", "description"]
+      hiddenRows: ["feedLocation", "siteLocation", "description"]
     };
 
     if (aFeedURI)
@@ -615,7 +625,7 @@ var PlacesUIUtils = {
     if (aDefaultInsertionPoint) {
       info.defaultInsertionPoint = aDefaultInsertionPoint;
       if (!aShowPicker)
-        info.hiddenRows.push("folder picker");
+        info.hiddenRows.push("folderPicker");
     }
     this._showBookmarkDialog(info, true);
   },
@@ -648,13 +658,16 @@ var PlacesUIUtils = {
    *        item identifier for which the properties are to be shown
    * @param aType
    *        item type, either "bookmark" or "folder"
+   * @param [optional] aReadOnly
+   *        states if properties dialog should be readonly
    * @return true if any transaction has been performed.
    */
-  showItemProperties: function PU_showItemProperties(aItemId, aType) {
+  showItemProperties: function PU_showItemProperties(aItemId, aType, aReadOnly) {
     var info = {
       action: "edit",
       type: aType,
-      itemId: aItemId
+      itemId: aItemId,
+      readOnly: aReadOnly
     };
     return this._showBookmarkDialog(info);
   },
@@ -688,7 +701,7 @@ var PlacesUIUtils = {
     if (aDefaultInsertionPoint) {
       info.defaultInsertionPoint = aDefaultInsertionPoint;
       if (!aShowPicker)
-        info.hiddenRows.push("folder picker");
+        info.hiddenRows.push("folderPicker");
     }
     return this._showBookmarkDialog(info);
   },
@@ -703,11 +716,7 @@ var PlacesUIUtils = {
    *        [optional] if true, the dialog is opened by its alternative
    *        chrome: uri.
    *
-   * Note: In minimal UI mode, we open the dialog non-modal on any system but
-   *       Mac OS X.
    * @return true if any transaction has been performed, false otherwise.
-   * Note: the return value of this method is not reliable in minimal UI mode
-   * since the dialog may not be opened modally.
    */
   _showBookmarkDialog: function PU__showBookmarkDialog(aInfo, aMinimalUI) {
     var dialogURL = aMinimalUI ?
@@ -716,9 +725,7 @@ var PlacesUIUtils = {
 
     var features;
     if (aMinimalUI)
-//@line 726 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/places/content/utils.js"
-      features = "centerscreen,chrome,dialog,resizable,dependent";
-//@line 728 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/places/content/utils.js"
+      features = "centerscreen,chrome,dialog,resizable,modal";
     else
       features = "centerscreen,chrome,modal,resizable=no";
     window.openDialog(dialogURL, "",  features, aInfo);
@@ -882,6 +889,9 @@ var PlacesUIUtils = {
     * {uri: string, isBookmark: boolean}
     */
   _openTabset: function PU__openTabset(aItemsToOpen, aEvent) {
+    if (!aItemsToOpen.length)
+      return;
+
     var urls = [];
     for (var i = 0; i < aItemsToOpen.length; i++) {
       var item = aItemsToOpen[i];
@@ -971,24 +981,34 @@ var PlacesUIUtils = {
     }
   },
 
+  /**
+   * Helper for guessing scheme from an url string.
+   * Used to avoid nsIURI overhead in frequently called UI functions.
+   *
+   * @param aUrlString the url to guess the scheme from.
+   * 
+   * @return guessed scheme for this url string.
+   *
+   * @note this is not supposed be perfect, so use it only for UI purposes.
+   */
+  guessUrlSchemeForUI: function PUU_guessUrlSchemeForUI(aUrlString) {
+    return aUrlString.substr(0, aUrlString.indexOf(":"));
+  },
+
   /**
    * Helper for the toolbar and menu views
    */
   createMenuItemForNode:
-  function PUU_createMenuItemForNode(aNode, aContainersMap) {
+  function PUU_createMenuItemForNode(aNode) {
     var element;
     var type = aNode.type;
     if (type == Ci.nsINavHistoryResultNode.RESULT_TYPE_SEPARATOR)
       element = document.createElement("menuseparator");
     else {
-      var iconURI = aNode.icon;
-      var iconURISpec = "";
-      if (iconURI)
-        iconURISpec = iconURI.spec;
-
       if (PlacesUtils.uriTypes.indexOf(type) != -1) {
         element = document.createElement("menuitem");
         element.className = "menuitem-iconic bookmark-item";
+        element.setAttribute("scheme", this.guessUrlSchemeForUI(aNode.uri));
       }
       else if (PlacesUtils.containerTypes.indexOf(type) != -1) {
         element = document.createElement("menu");
@@ -1011,13 +1031,11 @@ var PlacesUIUtils = {
         var popup = document.createElement("menupopup");
         popup.setAttribute("placespopup", "true");
         popup._resultNode = asContainer(aNode);
-//@line 1021 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/places/content/utils.js"
+//@line 1046 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/places/content/utils.js"
         // no context menu on mac
         popup.setAttribute("context", "placesContext");
-//@line 1024 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/places/content/utils.js"
+//@line 1049 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/places/content/utils.js"
         element.appendChild(popup);
-        if (aContainersMap)
-          aContainersMap.push({ resultNode: aNode, domNode: popup });
         element.className = "menu-iconic bookmark-item";
       }
       else
@@ -1025,61 +1043,56 @@ var PlacesUIUtils = {
 
       element.setAttribute("label", this.getBestTitle(aNode));
 
-      if (iconURISpec)
-        element.setAttribute("image", iconURISpec);
+      var icon = aNode.icon;
+      if (icon)
+        element.setAttribute("image", icon);
     }
     element.node = aNode;
-    element.node.viewIndex = 0;
+    element.node._DOMElement = element;
 
     return element;
   },
 
   cleanPlacesPopup: function PU_cleanPlacesPopup(aPopup) {
-    // Find static menuitems at the start and at the end of the menupopup,
-    // marked by builder="start" and builder="end" attributes, and set
-    // markers to keep track of their indices.
+    // Remove places popup children and update markers to keep track of
+    // their indices.
+    var start = aPopup._startMarker != -1 ? aPopup._startMarker + 1 : 0;
+    var end = aPopup._endMarker != -1 ? aPopup._endMarker :
+                                        aPopup.childNodes.length;
     var items = [];
-    aPopup._startMarker = -1;
-    aPopup._endMarker = -1;
-    for (var i = 0; i < aPopup.childNodes.length; ++i) {
+    var placesNodeFound = false;
+    for (var i = start; i < end; ++i) {
       var item = aPopup.childNodes[i];
-      if (item.getAttribute("builder") == "start") {
-        aPopup._startMarker = i;
-        continue;
-      }
       if (item.getAttribute("builder") == "end") {
+        // we need to do this for menus that have static content at the end but
+        // are initially empty, eg. the history menu, we need to know where to
+        // start inserting new items.
         aPopup._endMarker = i;
-        continue;
+        break;
       }
-      if ((aPopup._startMarker != -1) && (aPopup._endMarker == -1))
+      if (item.node) {
         items.push(item);
-    }
-
-    // If static items at the beginning were found, remove all items between
-    // them and the static content at the end.
-    for (var i = 0; i < items.length; ++i) {
-      // skip the empty menu item
-      if (aPopup._emptyMenuItem != items[i]) {
-        aPopup.removeChild(items[i]);
-        if (aPopup._endMarker > 0)
-          --aPopup._endMarker;
+        placesNodeFound = true;
       }
-    }
-
-    // If no static items were found at the beginning, remove all items before
-    // the static items at the end.
-    if (aPopup._startMarker == -1) {
-      var end = aPopup._endMarker == -1 ?
-                aPopup.childNodes.length - 1 : aPopup._endMarker - 1;
-      for (var i = end; i >= 0; i--) {
-        // skip the empty menu item
-        if (aPopup._emptyMenuItem != aPopup.childNodes[i]) {
-          aPopup.removeChild(aPopup.childNodes[i]);
-          if (aPopup._endMarker > 0)
-            --aPopup._endMarker;
+      else {
+        // This is static content...
+        if (!placesNodeFound)
+          // ...at the start of the popup
+          // Initialized in menu.xml, in the base binding
+          aPopup._startMarker++;
+        else {
+          // ...after places nodes
+          aPopup._endMarker = i;
+          break;
         }
       }
     }
+
+    for (var i = 0; i < items.length; ++i) {
+      aPopup.removeChild(items[i]);
+      if (aPopup._endMarker != -1)
+        aPopup._endMarker--;
+    }
   },
 
   getBestTitle: function PU_getBestTitle(aNode) {
@@ -1113,132 +1126,237 @@ var PlacesUIUtils = {
     return this.leftPaneQueries;
   },
 
-  // get the folder id for the organizer left-pane folder
+  // Get the folder id for the organizer left-pane folder.
   get leftPaneFolderId() {
     var leftPaneRoot = -1;
     var allBookmarksId;
-    var items = PlacesUtils.annotations
-                           .getItemsWithAnnotation(ORGANIZER_FOLDER_ANNO, {});
-    if (items.length != 0 && items[0] != -1) {
+
+    // Shortcuts to services.
+    var bs = PlacesUtils.bookmarks;
+    var as = PlacesUtils.annotations;
+
+    // Get all items marked as being the left pane folder.  We should only have
+    // one of them.
+    var items = as.getItemsWithAnnotation(ORGANIZER_FOLDER_ANNO, {});
+    if (items.length > 1) {
+      // Something went wrong, we cannot have more than one left pane folder,
+      // remove all left pane folders and continue.  We will create a new one.
+      items.forEach(bs.removeItem);
+    }
+    else if (items.length == 1 && items[0] != -1) {
       leftPaneRoot = items[0];
-      // check organizer left pane version
-      var version = PlacesUtils.annotations
-                               .getItemAnnotation(leftPaneRoot, ORGANIZER_FOLDER_ANNO);
+      // Check organizer left pane version.
+      var version = as.getItemAnnotation(leftPaneRoot, ORGANIZER_FOLDER_ANNO);
       if (version != ORGANIZER_LEFTPANE_VERSION) {
         // If version is not valid we must rebuild the left pane.
-        PlacesUtils.bookmarks.removeFolder(leftPaneRoot);
+        bs.removeItem(leftPaneRoot);
         leftPaneRoot = -1;
       }
     }
 
+    var queriesTitles = {
+      "PlacesRoot": "",
+      "History": this.getString("OrganizerQueryHistory"),
+      // TODO: Bug 489681, Tags needs its own string in places.properties
+      "Tags": bs.getItemTitle(PlacesUtils.tagsFolderId),
+      "AllBookmarks": this.getString("OrganizerQueryAllBookmarks"),
+      "Downloads": this.getString("OrganizerQueryDownloads"),
+      "BookmarksToolbar": null,
+      "BookmarksMenu": null,
+      "UnfiledBookmarks": null
+    };
+
     if (leftPaneRoot != -1) {
-      // Build the leftPaneQueries Map
+      // A valid left pane folder has been found.
+      // Build the leftPaneQueries Map.  This is used to quickly access them
+      // associating a mnemonic name to the real item ids.
       delete this.leftPaneQueries;
       this.leftPaneQueries = {};
-      var items = PlacesUtils.annotations
-                             .getItemsWithAnnotation(ORGANIZER_QUERY_ANNO, {});
-      for (var i=0; i < items.length; i++) {
-        var queryName = PlacesUtils.annotations
-                                   .getItemAnnotation(items[i], ORGANIZER_QUERY_ANNO);
+      var items = as.getItemsWithAnnotation(ORGANIZER_QUERY_ANNO, {});
+      // While looping through queries we will also check for titles validity.
+      for (var i = 0; i < items.length; i++) {
+        var queryName = as.getItemAnnotation(items[i], ORGANIZER_QUERY_ANNO);
         this.leftPaneQueries[queryName] = items[i];
+        // Titles could have been corrupted or the user could have changed his
+        // locale.  Check title is correctly set and eventually fix it.
+        if (bs.getItemTitle(items[i]) != queriesTitles[queryName])
+          bs.setItemTitle(items[i], queriesTitles[queryName]);
       }
       delete this.leftPaneFolderId;
       return this.leftPaneFolderId = leftPaneRoot;
     }
 
     var self = this;
-    const EXPIRE_NEVER = PlacesUtils.annotations.EXPIRE_NEVER;
     var callback = {
-      runBatched: function(aUserData) {
+      // Helper to create an organizer special query.
+      create_query: function CB_create_query(aQueryName, aParentId, aQueryUrl) {
+        let itemId = bs.insertBookmark(aParentId,
+                                       PlacesUtils._uri(aQueryUrl),
+                                       bs.DEFAULT_INDEX,
+                                       queriesTitles[aQueryName]);
+        // Mark as special organizer query.
+        as.setItemAnnotation(itemId, ORGANIZER_QUERY_ANNO, aQueryName,
+                             0, as.EXPIRE_NEVER);
+        // We should never backup this, since it changes between profiles.
+        as.setItemAnnotation(itemId, EXCLUDE_FROM_BACKUP_ANNO, 1,
+                             0, as.EXPIRE_NEVER);
+        // Add to the queries map.
+        self.leftPaneQueries[aQueryName] = itemId;
+        return itemId;
+      },
+
+      // Helper to create an organizer special folder.
+      create_folder: function CB_create_folder(aFolderName, aParentId, aIsRoot) {
+              // Left Pane Root Folder.
+        let folderId = bs.createFolder(aParentId,
+                                       queriesTitles[aFolderName],
+                                       bs.DEFAULT_INDEX);
+        // We should never backup this, since it changes between profiles.
+        as.setItemAnnotation(folderId, EXCLUDE_FROM_BACKUP_ANNO, 1,
+                             0, as.EXPIRE_NEVER);
+        // Disallow manipulating this folder within the organizer UI.
+        bs.setFolderReadonly(folderId, true);
+
+        if (aIsRoot) {
+          // Mark as special left pane root.
+          as.setItemAnnotation(folderId, ORGANIZER_FOLDER_ANNO,
+                               ORGANIZER_LEFTPANE_VERSION,
+                               0, as.EXPIRE_NEVER);
+        }
+        else {
+          // Mark as special organizer folder.
+          as.setItemAnnotation(folderId, ORGANIZER_QUERY_ANNO, aFolderName,
+                           0, as.EXPIRE_NEVER);
+          self.leftPaneQueries[aFolderName] = folderId;
+        }
+        return folderId;
+      },
+
+      runBatched: function CB_runBatched(aUserData) {
         delete self.leftPaneQueries;
         self.leftPaneQueries = { };
 
-        // Left Pane Root Folder
-        leftPaneRoot = PlacesUtils.bookmarks.createFolder(PlacesUtils.placesRootId, "", -1);
-        // ensure immediate children can't be removed
-        PlacesUtils.bookmarks.setFolderReadonly(leftPaneRoot, true);
+        // Left Pane Root Folder.
+        leftPaneRoot = this.create_folder("PlacesRoot", bs.placesRoot, true);
 
-        // History Query
-        let uri = PlacesUtils._uri("place:sort=4&");
-        let title = self.getString("OrganizerQueryHistory");
-        let itemId = PlacesUtils.bookmarks.insertBookmark(leftPaneRoot, uri, -1, title);
-        PlacesUtils.annotations.setItemAnnotation(itemId, ORGANIZER_QUERY_ANNO,
-                                                  "History", 0, EXPIRE_NEVER);
-        self.leftPaneQueries["History"] = itemId;
+        // History Query.
+        this.create_query("History", leftPaneRoot,
+                          "place:type=" +
+                          Ci.nsINavHistoryQueryOptions.RESULTS_AS_DATE_QUERY +
+                          "&sort=" +
+                          Ci.nsINavHistoryQueryOptions.SORT_BY_DATE_DESCENDING);
 
-        // XXX: Downloads
+        // XXX: Downloads.
 
-        // Tags Query
-        uri = PlacesUtils._uri("place:type=" +
+        // Tags Query.
+        this.create_query("Tags", leftPaneRoot,
+                          "place:type=" +
                           Ci.nsINavHistoryQueryOptions.RESULTS_AS_TAG_QUERY +
                           "&sort=" +
                           Ci.nsINavHistoryQueryOptions.SORT_BY_TITLE_ASCENDING);
-        title = PlacesUtils.bookmarks.getItemTitle(PlacesUtils.tagsFolderId);
-        itemId = PlacesUtils.bookmarks.insertBookmark(leftPaneRoot, uri, -1, title);
-        PlacesUtils.annotations.setItemAnnotation(itemId, ORGANIZER_QUERY_ANNO,
-                                                  "Tags", 0, EXPIRE_NEVER);
-        self.leftPaneQueries["Tags"] = itemId;
 
-        // All Bookmarks Folder
-        title = self.getString("OrganizerQueryAllBookmarks");
-        itemId = PlacesUtils.bookmarks.createFolder(leftPaneRoot, title, -1);
-        allBookmarksId = itemId;
-        PlacesUtils.annotations.setItemAnnotation(itemId, ORGANIZER_QUERY_ANNO,
-                                                  "AllBookmarks", 0, EXPIRE_NEVER);
-        self.leftPaneQueries["AllBookmarks"] = itemId;
+        // All Bookmarks Folder.
+        allBookmarksId = this.create_folder("AllBookmarks", leftPaneRoot, false);
 
-        // disallow manipulating this folder within the organizer UI
-        PlacesUtils.bookmarks.setFolderReadonly(allBookmarksId, true);
+        // All Bookmarks->Bookmarks Toolbar Query.
+        this.create_query("BookmarksToolbar", allBookmarksId,
+                          "place:folder=TOOLBAR");
 
-        // All Bookmarks->Bookmarks Toolbar Query
-        uri = PlacesUtils._uri("place:folder=TOOLBAR");
-        itemId = PlacesUtils.bookmarks.insertBookmark(allBookmarksId, uri, -1, null);
-        PlacesUtils.annotations.setItemAnnotation(itemId, ORGANIZER_QUERY_ANNO,
-                                                  "BookmarksToolbar", 0, EXPIRE_NEVER);
-        self.leftPaneQueries["BookmarksToolbar"] = itemId;
+        // All Bookmarks->Bookmarks Menu Query.
+        this.create_query("BookmarksMenu", allBookmarksId,
+                          "place:folder=BOOKMARKS_MENU");
 
-        // All Bookmarks->Bookmarks Menu Query
-        uri = PlacesUtils._uri("place:folder=BOOKMARKS_MENU");
-        itemId = PlacesUtils.bookmarks.insertBookmark(allBookmarksId, uri, -1, null);
-        PlacesUtils.annotations.setItemAnnotation(itemId, ORGANIZER_QUERY_ANNO,
-                                                  "BookmarksMenu", 0, EXPIRE_NEVER);
-        self.leftPaneQueries["BookmarksMenu"] = itemId;
-
-        // All Bookmarks->Unfiled bookmarks
-        uri = PlacesUtils._uri("place:folder=UNFILED_BOOKMARKS");
-        itemId = PlacesUtils.bookmarks.insertBookmark(allBookmarksId, uri, -1, null);
-        PlacesUtils.annotations.setItemAnnotation(itemId, ORGANIZER_QUERY_ANNO,
-                                                  "UnfiledBookmarks", 0,
-                                                  EXPIRE_NEVER);
-        self.leftPaneQueries["UnfiledBookmarks"] = itemId;
-
-        // disallow manipulating this folder within the organizer UI
-        PlacesUtils.bookmarks.setFolderReadonly(leftPaneRoot, true);
+        // All Bookmarks->Unfiled Bookmarks Query.
+        this.create_query("UnfiledBookmarks", allBookmarksId,
+                          "place:folder=UNFILED_BOOKMARKS");
       }
     };
-    PlacesUtils.bookmarks.runInBatchMode(callback, null);
-    PlacesUtils.annotations.setItemAnnotation(leftPaneRoot,
-                                              ORGANIZER_FOLDER_ANNO,
-                                              ORGANIZER_LEFTPANE_VERSION,
-                                              0, EXPIRE_NEVER);
+    bs.runInBatchMode(callback, null);
+
     delete this.leftPaneFolderId;
     return this.leftPaneFolderId = leftPaneRoot;
   },
 
+  /**
+   * Get the folder id for the organizer left-pane folder.
+   */
   get allBookmarksFolderId() {
     // ensure the left-pane root is initialized;
     this.leftPaneFolderId;
     delete this.allBookmarksFolderId;
     return this.allBookmarksFolderId = this.leftPaneQueries["AllBookmarks"];
+  },
+
+  /**
+   * If an item is a left-pane query, returns the name of the query
+   * or an empty string if not.
+   *
+   * @param aItemId id of a container
+   * @returns the name of the query, or empty string if not a left-pane query
+   */
+  getLeftPaneQueryNameFromId: function PU_getLeftPaneQueryNameFromId(aItemId) {
+    var queryName = "";
+    // If the let pane hasn't been built, use the annotation service
+    // directly, to avoid building the left pane too early.
+    if (this.__lookupGetter__("leftPaneFolderId")) {
+      try {
+        queryName = PlacesUtils.annotations.
+                                getItemAnnotation(aItemId, ORGANIZER_QUERY_ANNO);
+      }
+      catch (ex) {
+        // doesn't have the annotation
+        queryName = "";
+      }
+    }
+    else {
+      // If the left pane has already been built, use the name->id map
+      // cached in PlacesUIUtils.
+      for (let [name, id] in Iterator(this.leftPaneQueries)) {
+        if (aItemId == id)
+          queryName = name;
+      }
+    }
+    return queryName; 
+  },
+
+  /**
+  * Add, update or remove the livemark status menuitem.
+  * @param aPopup
+  *        The livemark container popup
+  */
+  ensureLivemarkStatusMenuItem:
+  function PU_ensureLivemarkStatusMenuItem(aPopup) {
+    var itemId = aPopup._resultNode.itemId;
+
+    var lmStatus = null;
+    if (PlacesUtils.annotations
+                   .itemHasAnnotation(itemId, "livemark/loadfailed"))
+      lmStatus = "bookmarksLivemarkFailed";
+    else if (PlacesUtils.annotations
+                        .itemHasAnnotation(itemId, "livemark/loading"))
+      lmStatus = "bookmarksLivemarkLoading";
+
+    if (lmStatus && !aPopup._lmStatusMenuItem) {
+      // Create the status menuitem and cache it in the popup object.
+      aPopup._lmStatusMenuItem = document.createElement("menuitem");
+      aPopup._lmStatusMenuItem.setAttribute("lmStatus", lmStatus);
+      aPopup._lmStatusMenuItem.setAttribute("label", this.getString(lmStatus));
+      aPopup._lmStatusMenuItem.setAttribute("disabled", true);
+      aPopup.insertBefore(aPopup._lmStatusMenuItem,
+                          aPopup.childNodes.item(aPopup._startMarker + 1));
+      aPopup._startMarker++;
+    }
+    else if (lmStatus &&
+             aPopup._lmStatusMenuItem.getAttribute("lmStatus") != lmStatus) {
+      // Status has changed, update the cached status menuitem.
+      aPopup._lmStatusMenuItem.setAttribute("label",
+                                            this.getString(lmStatus));
+    }
+    else if (!lmStatus && aPopup._lmStatusMenuItem){
+      // No status, remove the cached menuitem.
+      aPopup.removeChild(aPopup._lmStatusMenuItem);
+      aPopup._lmStatusMenuItem = null;
+      aPopup._startMarker--;
+    }
   }
 };
-
-PlacesUIUtils.placesFlavors = [PlacesUtils.TYPE_X_MOZ_PLACE_CONTAINER,
-                             PlacesUtils.TYPE_X_MOZ_PLACE_SEPARATOR,
-                             PlacesUtils.TYPE_X_MOZ_PLACE];
-
-PlacesUIUtils.GENERIC_VIEW_DROP_TYPES = [PlacesUtils.TYPE_X_MOZ_PLACE_CONTAINER,
-                                       PlacesUtils.TYPE_X_MOZ_PLACE_SEPARATOR,
-                                       PlacesUtils.TYPE_X_MOZ_PLACE,
-                                       PlacesUtils.TYPE_X_MOZ_URL,
-                                       PlacesUtils.TYPE_UNICODE];
