@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/components/preferences/permissions.js"
+//@line 39 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/preferences/permissions.js"
 
 const nsIPermissionManager = Components.interfaces.nsIPermissionManager;
 const nsICookiePermission = Components.interfaces.nsICookiePermission;
@@ -45,7 +45,10 @@ var gPermissionManager = {
     cycleHeader: function(column) {},
     getRowProperties: function(row,prop){},
     getColumnProperties: function(column,prop){},
-    getCellProperties: function(row,column,prop){}
+    getCellProperties: function(row,column,prop){
+      if (column.element.getAttribute("id") == "siteCol")
+        prop.AppendElement(this._ltrAtom);
+    }
   },
   
   _getCapabilityString: function (aCapability)
@@ -177,6 +180,10 @@ var gPermissionManager = {
     this._loadPermissions();
     
     urlField.focus();
+
+    this._ltrAtom = Components.classes["@mozilla.org/atom-service;1"]
+                              .getService(Components.interfaces.nsIAtomService)
+                              .getAtom("ltr");
   },
   
   uninit: function ()
@@ -327,7 +334,7 @@ var gPermissionManager = {
       var pbi = Components.classes["@mozilla.org/preferences-service;1"]
                           .getService(Components.interfaces.nsIPrefBranch2);
       var prefList = [["xpinstall.whitelist.add", nsIPermissionManager.ALLOW_ACTION],
-                      ["xpinstall.whitelist.add.103", nsIPermissionManager.ALLOW_ACTION],
+                      ["xpinstall.whitelist.add.36", nsIPermissionManager.ALLOW_ACTION],
                       ["xpinstall.blacklist.add", nsIPermissionManager.DENY_ACTION]];
 
       for (var i = 0; i < prefList.length; ++i) {
