@@ -1,4 +1,4 @@
-//@line 40 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/components/search/content/engineManager.js"
+//@line 40 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/search/content/engineManager.js"
 
 const Ci = Components.interfaces;
 const Cc = Components.classes;
@@ -130,29 +130,20 @@ var gEngineManagerDialog = {
       var eduplicate = false;
 
       if (alias.value != "") {
-        var searchService = Cc["@mozilla.org/browser/search-service;1"].
-                            getService(Ci.nsIBrowserSearchService);
-        var engine = searchService.getEngineByAlias(alias.value);
+        try {
+          let bmserv = Cc["@mozilla.org/browser/nav-bookmarks-service;1"].
+                       getService(Ci.nsINavBookmarksService);
+          if (bmserv.getURIForKeyword(alias.value))
+            bduplicate = true;
+        } catch(ex) {}
 
-        if (engine) {
-          if (engine.name != selectedEngine.name)
+        // Check for duplicates in changes we haven't committed yet
+        let engines = gEngineView._engineStore.engines;
+        for each (let engine in engines) {
+          if (engine.alias == alias.value && 
+              engine.name != selectedEngine.name) {
             eduplicate = true;
-        } else {
-          try {
-            var bmserv = Cc["@mozilla.org/browser/nav-bookmarks-service;1"].
-                         getService(Ci.nsINavBookmarksService);
-            if (bmserv.getURIForKeyword(alias.value))
-              bduplicate = true;
-          } catch(ex) {}
-
-          // Check for duplicates in changes we haven't committed yet
-          var engines = gEngineView._engineStore.engines;
-          for each (var engine in engines) {
-            if (engine.alias == alias.value && 
-                engine.name != selectedEngine.name) {
-              eduplicate = true;
-              break;
-            }
+            break;
           }
         }
       }
@@ -195,22 +186,13 @@ var gEngineManagerDialog = {
   }
 };
 
-var gDragObserver = {
-  onDragStart: function (aEvent, aXferData, aDragAction) {
-    var selectedIndex = gEngineView.selectedIndex;
-    if (selectedIndex == -1)
-      return;
-
-    aXferData.data = new TransferData();
-    aXferData.data.addDataForFlavour(ENGINE_FLAVOR, selectedIndex.toString());
-
-    aDragAction.action = Ci.nsIDragService.DRAGDROP_ACTION_MOVE;
-  },
-  onDrop: function (aEvent, aXferData, aDragSession) { },
-  onDragExit: function (aEvent, aDragSession) { },
-  onDragOver: function (aEvent, aFlavour, aDragSession) { },
-  getSupportedFlavours: function() { return null; }
-};
+function onDragEngineStart(event) {
+  var selectedIndex = gEngineView.selectedIndex;
+  if (selectedIndex > 0) {
+    event.dataTransfer.setData(ENGINE_FLAVOR, selectedIndex.toString());
+    event.dataTransfer.effectAllowed = "move";
+  }
+}
 
 // "Operation" objects
 function EngineMoveOp(aEngineClone, aNewIndex) {
