@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/base/content/web-panels.js"
+//@line 39 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/base/content/web-panels.js"
 
 const NS_ERROR_MODULE_NETWORK = 2152398848;
 const NS_NET_STATUS_READ_FROM = NS_ERROR_MODULE_NETWORK + 8;
@@ -78,7 +78,6 @@ function load()
                              null, null);
     }
 
-    gNavigatorBundle = document.getElementById("bundle_browser");
     gLoadFired = true;
 }
 
