@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/components/feeds/src/FeedConverter.js"
+//@line 39 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/feeds/src/FeedConverter.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -124,17 +124,7 @@ FeedConverter.prototype = {
    * Records if the feed was sniffed
    */
   _sniffed: false,
-  
-  /**
-   * See nsIStreamConverter.idl
-   */
-  canConvert: function FC_canConvert(sourceType, destinationType) {
-    // We only support one conversion.
-    return destinationType == TYPE_ANY && ((sourceType == TYPE_MAYBE_FEED) ||
-                                           (sourceType == TYPE_MAYBE_VIDEO) ||
-                                           (sourceType == TYPE_MAYBE_AUDIO));
-  },
-  
+
   /**
    * See nsIStreamConverter.idl
    */
@@ -246,18 +236,13 @@ FeedConverter.prototype = {
           getService(Ci.nsIIOService);
       var chromeChannel;
 
-      // show the feed page if it wasn't sniffed and we have a document,
-      // or we have a document, title, and link or id
-      if (result.doc && (!this._sniffed ||
-          (result.doc.title && (result.doc.link || result.doc.id)))) {
+      // If there was no automatic handler, or this was a podcast,
+      // photostream or some other kind of application, show the preview page
+      // if the parser returned a document.
+      if (result.doc) {
 
-        // If there was no automatic handler, or this was a podcast,
-        // photostream or some other kind of application, we must always
-        // show the preview page.
-        
         // Store the result in the result service so that the display
         // page can access it.
-
         feedService.addFeedResult(result);
 
         // Now load the actual XUL document.
@@ -325,7 +310,7 @@ FeedConverter.prototype = {
   /**
    * See nsIRequestObserver.idl
    */
-  onStopRequest: function FC_onStopReqeust(request, context, status) {
+  onStopRequest: function FC_onStopRequest(request, context, status) {
     if (this._processor)
       this._processor.onStopRequest(request, context, status);
   },
@@ -355,7 +340,7 @@ var FeedConverterFactory = {
     if (iid.equals(Ci.nsIFactory) ||
         iid.equals(Ci.nsISupports))
       return this;
-    throw Cr.NS_ERROR_NOT_IMPLEMENTED;
+    throw Cr.NS_ERROR_NO_INTERFACE;
   },
 };
 
@@ -410,10 +395,22 @@ var FeedResultService = {
       else
         spec = "feed:" + spec;
 
-      var ss = 
-          Cc["@mozilla.org/browser/shell-service;1"].
-          getService(Ci.nsIShellService);
-      ss.openApplicationWithURI(clientApp, spec);
+      // Retrieving the shell service might fail on some systems, most
+      // notably systems where GNOME is not installed.
+      try {
+        var ss =
+            Cc["@mozilla.org/browser/shell-service;1"].
+            getService(Ci.nsIShellService);
+        ss.openApplicationWithURI(clientApp, spec);
+      } catch(e) {
+        // If we couldn't use the shell service, fallback to using a
+        // nsIProcess instance
+        var p =
+            Cc["@mozilla.org/process/util;1"].
+            createInstance(Ci.nsIProcess);
+        p.init(clientApp);
+        p.run(false, [spec], 1);
+      }
       break;
 
     default:
@@ -650,7 +647,7 @@ function NSGetModule(cm, file) {
   return Module;
 }
 
-//@line 44 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/toolkit/content/debug.js"
+//@line 44 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/content/debug.js"
 
 var EXPORTED_SYMBOLS = ["NS_ASSERT"];
 
@@ -732,7 +729,7 @@ function NS_ASSERT(condition, message) {
            getService(Components.interfaces.nsIPromptService);
   ps.alert(source, "Assertion Failed", assertionText + stackText);
 }
-//@line 37 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/components/feeds/src/GenericFactory.js"
+//@line 37 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/feeds/src/GenericFactory.js"
 
 /**
  * An object implementing nsIFactory that can construct other objects upon
