@@ -1,4 +1,4 @@
-//@line 42 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 42 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/feeds/src/FeedWriter.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -641,7 +641,7 @@ FeedWriter.prototype = {
    * @returns The display name of the application represented by the file.
    */
   _getFileDisplayName: function FW__getFileDisplayName(file) {
-//@line 702 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 702 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/feeds/src/FeedWriter.js"
     var ios = 
         Cc["@mozilla.org/network/io-service;1"].
         getService(Ci.nsIIOService);
@@ -699,9 +699,9 @@ FeedWriter.prototype = {
           // XXXben - we need to compare this with the running instance executable
           //          just don't know how to do that via script...
           // XXXmano TBD: can probably add this to nsIShellService
-//@line 765 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 765 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/feeds/src/FeedWriter.js"
           if (fp.file.leafName != "firefox-bin") {
-//@line 768 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 768 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/feeds/src/FeedWriter.js"
             this._initMenuItemWithFile(this._contentSandbox.selectedAppMenuItem,
                                        this._selectedApp);
 
@@ -782,8 +782,6 @@ FeedWriter.prototype = {
 
   // nsIDomEventListener
   handleEvent: function(event) {
-    // see comments in the write method
-    event = new XPCNativeWrapper(event);
     if (event.target.ownerDocument != this._document) {
       LOG("FeedWriter.handleEvent: Someone passed the feed writer as a listener to the events of another document!");
       return;
@@ -960,6 +958,7 @@ FeedWriter.prototype = {
     // "Choose Application..." menuitem
     menuItem = this._document.createElementNS(XUL_NS, "menuitem");
     menuItem.id = "chooseApplicationMenuItem";
+    menuItem.className = "menuitem-iconic";
     menuItem.setAttribute("label", this._getString("chooseApplicationMenuItem"));
 
     this._contentSandbox.chooseAppMenuItem = menuItem;
@@ -1051,8 +1050,8 @@ FeedWriter.prototype = {
         this._document.getElementById("feedSubscriptionInfo2");
       this._contentSandbox.feedinfo2Str = this._getString(textfeedinfo2);
       this._contentSandbox.header = header;
-      codeStr = "feedinfo1.value = feedinfo1Str; " +
-                "feedinfo2.value = feedinfo2Str; " +
+      codeStr = "feedinfo1.textContent = feedinfo1Str; " +
+                "feedinfo2.textContent = feedinfo2Str; " +
                 "header.setAttribute('firstrun', 'true');"
       Cu.evalInSandbox(codeStr, this._contentSandbox);
       prefs.setBoolPref(PREF_SHOW_FIRST_RUN_UI, false);
@@ -1088,10 +1087,7 @@ FeedWriter.prototype = {
 
   // nsIFeedWriter
   init: function FW_init(aWindow) {
-    // Explicitly wrap |window| in an XPCNativeWrapper to make sure
-    // it's a real native object! This will throw an exception if we
-    // get a non-native object.
-    var window = new XPCNativeWrapper(aWindow);
+    var window = aWindow;
     this._feedURI = this._getOriginalURI(window);
     if (!this._feedURI)
       return;
@@ -1202,7 +1198,7 @@ FeedWriter.prototype = {
     var selectedItem = this._getSelectedItemFromMenulist(handlersMenuList);
 
     // Show the file picker before subscribing if the
-    // choose application menuitem was choosen using the keyboard
+    // choose application menuitem was chosen using the keyboard
     if (selectedItem.id == "chooseApplicationMenuItem") {
       if (!this._chooseClientApp())
         return;
@@ -1268,10 +1264,8 @@ FeedWriter.prototype = {
 
   // nsIObserver
   observe: function FW_observe(subject, topic, data) {
-    subject = new XPCNativeWrapper(subject);
-
     if (!this._window) {
-      // this._window is null unless this.write was called with a trusted
+      // this._window is null unless this.init was called with a trusted
       // window object.
       return;
     }
@@ -1311,26 +1305,21 @@ FeedWriter.prototype = {
   _setFaviconForWebReader:
   function FW__setFaviconForWebReader(aURI, aMenuItem) {
     var faviconsSvc = this._faviconService;
-    var faviconURL = null;
+    var faviconURI = null;
     try {
-      faviconURL = faviconsSvc.getFaviconForPage(aURI);
+      faviconURI = faviconsSvc.getFaviconForPage(aURI);
     }
     catch(ex) { }
 
-    if (faviconURL) {
-      var mimeType = { };
-      var bytes = faviconsSvc.getFaviconData(faviconURL, mimeType,
-                                             { /* dataLen */ });
-      if (bytes) {
-        var dataURI = "data:" + mimeType.value + ";" + "base64," +
-                      btoa(String.fromCharCode.apply(null, bytes));
-
+    if (faviconURI) {
+      var dataURL = faviconsSvc.getFaviconDataAsDataURL(faviconURI);
+      if (dataURL) {
         this._contentSandbox.menuItem = aMenuItem;
-        this._contentSandbox.dataURI = dataURI;
-        var codeStr = "menuItem.setAttribute('image', dataURI);";
+        this._contentSandbox.dataURL = dataURL;
+        var codeStr = "menuItem.setAttribute('image', dataURL);";
         Cu.evalInSandbox(codeStr, this._contentSandbox);
         this._contentSandbox.menuItem = null;
-        this._contentSandbox.dataURI = null;
+        this._contentSandbox.dataURL = null;
 
         return true;
       }
@@ -1341,8 +1330,6 @@ FeedWriter.prototype = {
 
    // nsINavHistoryService
    onPageChanged: function FW_onPageChanged(aURI, aWhat, aValue) {
-    aURI = new XPCNativeWrapper(aURI);
-
      if (aWhat == Ci.nsINavHistoryObserver.ATTRIBUTE_FAVICON) {
        // Go through the readers menu and look for the corresponding
        // reader menu-item for the page if any.
@@ -1362,6 +1349,7 @@ FeedWriter.prototype = {
    onEndUpdateBatch: function() { },
    onVisit: function() { },
    onTitleChanged: function() { },
+   onBeforeDeleteURI: function() { },
    onDeleteURI: function() { },
    onClearHistory: function() { },
    onPageExpired: function() { },
