@@ -1,4 +1,4 @@
-//@line 37 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 37 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/nsBrowserContentHandler.js"
 
 const nsISupports            = Components.interfaces.nsISupports;
 
@@ -29,7 +29,7 @@ const nsIWebNavigationInfo   = Components.interfaces.nsIWebNavigationInfo;
 const nsIBrowserSearchService = Components.interfaces.nsIBrowserSearchService;
 const nsICommandLineValidator = Components.interfaces.nsICommandLineValidator;
 
-const NS_BINDING_ABORTED = 0x804b0002;
+const NS_BINDING_ABORTED = Components.results.NS_BINDING_ABORTED;
 const NS_ERROR_WONT_HANDLE_CONTENT = 0x805d0001;
 const NS_ERROR_ABORT = Components.results.NS_ERROR_ABORT;
 
@@ -115,7 +115,7 @@ function needHomepageOverride(prefb) {
 }
 
 // Copies a pref override file into the user's profile pref-override folder,
-// and then tells the pref service to reload it's default prefs.
+// and then tells the pref service to reload its default prefs.
 function copyPrefOverride() {
   try {
     var fileLocator = Components.classes["@mozilla.org/file/directory_service;1"]
@@ -222,29 +222,11 @@ function getMostRecentWindow(aType) {
   return wm.getMostRecentWindow(aType);
 }
 
-//@line 268 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/nsBrowserContentHandler.js"
-
 // this returns the most recent non-popup browser window
 function getMostRecentBrowserWindow() {
-  var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
-                     .getService(Components.interfaces.nsIWindowMediator);
-
-//@line 275 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/nsBrowserContentHandler.js"
-  var win = wm.getMostRecentWindow("navigator:browser", true);
-
-  // if we're lucky, this isn't a popup, and we can just return this
-  if (win && win.document.documentElement.getAttribute("chromehidden")) {
-    var windowList = wm.getEnumerator("navigator:browser", true);
-    // this is oldest to newest, so this gets a bit ugly
-    while (windowList.hasMoreElements()) {
-      var nextWin = windowList.getNext();
-      if (!nextWin.document.documentElement.getAttribute("chromehidden"))
-        win = nextWin;
-    }
-  }
-//@line 300 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/nsBrowserContentHandler.js"
-
-  return win;
+  var browserGlue = Components.classes["@mozilla.org/browser/browserglue;1"]
+                              .getService(Components.interfaces.nsIBrowserGlue);
+  return browserGlue.getMostRecentBrowserWindow();
 }
 
 function doSearch(searchTerm, cmdLine) {
@@ -461,7 +443,19 @@ var nsBrowserContentHandler = {
       cmdLine.preventDefault = true;
     }
 
-//@line 531 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/nsBrowserContentHandler.js"
+    var fileParam = cmdLine.handleFlagWithParam("file", false);
+    if (fileParam) {
+      var file = cmdLine.resolveFile(fileParam);
+      var ios = Components.classes["@mozilla.org/network/io-service;1"]
+                          .getService(Components.interfaces.nsIIOService);
+      var uri = ios.newFileURI(file);
+      openWindow(null, this.chromeURL, "_blank", 
+                 "chrome,dialog=no,all" + this.getFeatures(cmdLine),
+                 uri.spec);
+      cmdLine.preventDefault = true;
+    }
+
+//@line 506 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/nsBrowserContentHandler.js"
   },
 
   helpInfo : "  -browser            Open a browser window.\n",
@@ -670,13 +664,13 @@ var nsDefaultCommandLineHandler = {
   // running and have already been handled. This is compared against uri's
   // opened using DDE on Win32 so we only open one of the requests.
   _handledURIs: [ ],
-//@line 742 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 717 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/nsBrowserContentHandler.js"
 
   /* nsICommandLineHandler */
   handle : function dch_handle(cmdLine) {
     var urilist = [];
 
-//@line 768 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 743 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/nsBrowserContentHandler.js"
 
     try {
       var ar;
@@ -831,9 +825,9 @@ var Module = {
 
     registerType("text/html");
     registerType("application/vnd.mozilla.xul+xml");
-//@line 923 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 898 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/nsBrowserContentHandler.js"
     registerType("image/svg+xml");
-//@line 925 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 900 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/components/nsBrowserContentHandler.js"
     registerType("text/rdf");
     registerType("text/xml");
     registerType("application/xhtml+xml");
@@ -846,7 +840,6 @@ var Module = {
     registerType("image/bmp");
     registerType("image/x-icon");
     registerType("image/vnd.microsoft.icon");
-    registerType("image/x-xbitmap");
     registerType("application/http-index-format");
 
     var catMan = Components.classes["@mozilla.org/categorymanager;1"]
