@@ -25,7 +25,8 @@
  *   Masayuki Nakano <masayuki@d-toybox.com>
  *   Robert Sayre <sayrer@gmail.com> (JS port)
  *   Phil Ringnalda <philringnalda@gmail.com>
- *   Marco Bonardo <mak77@supereva.it>
+ *   Marco Bonardo <mak77@bonardo.net>
+ *   Takeshi Ichimaru <ayakawa.m@gmail.com>
  *
  * Alternatively, the contents of this file may be used under the
  * terms of either the GNU General Public License Version 2 or later
@@ -47,7 +48,7 @@ const Cc = Components.classes;
 const Ci = Components.interfaces;
 const Cr = Components.results;
 
-//@line 36 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/toolkit/components/url-classifier/content/moz/lang.js"
+//@line 36 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/components/url-classifier/content/moz/lang.js"
 
 
 /**
@@ -127,7 +128,7 @@ Function.prototype.inherits = function(parentCtor) {
   this.superClass_ = parentCtor.prototype;
   this.prototype = new tempCtor();
 }
-//@line 36 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/toolkit/components/url-classifier/content/moz/observer.js"
+//@line 36 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/components/url-classifier/content/moz/observer.js"
 
 
 // A couple of classes to simplify creating observers. 
@@ -227,7 +228,7 @@ G_ObserverServiceObserver.prototype.observe_ = function(subject, topic, data) {
     this.unregister();
 }
 
-//@line 36 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/toolkit/components/url-classifier/content/moz/alarm.js"
+//@line 36 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/components/url-classifier/content/moz/alarm.js"
 
 
 // An Alarm fires a callback after a certain amount of time, or at
@@ -373,23 +374,17 @@ G_ConditionalAlarm.prototype.notify = function(timer) {
     this.cancel();
   }
 }
-//@line 53 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/toolkit/components/places/src/nsLivemarkService.js"
-
-function LOG(str) {
-  dump("*** " + str + "\n");
-}
+//@line 54 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/components/places/src/nsLivemarkService.js"
 
 const LS_CLASSID = Components.ID("{dca61eb5-c7cd-4df1-b0fb-d0722baba251}");
 const LS_CLASSNAME = "Livemark Service";
 const LS_CONTRACTID = "@mozilla.org/browser/livemark-service;2";
 
-const PLACES_BUNDLE_URI = "chrome://places/locale/places.properties";
-const DEFAULT_LOAD_MSG = "Live Bookmark loading...";
-const DEFAULT_FAIL_MSG = "Live Bookmark feed failed to load.";
 const LMANNO_FEEDURI = "livemark/feedURI";
 const LMANNO_SITEURI = "livemark/siteURI";
 const LMANNO_EXPIRATION = "livemark/expiration";
 const LMANNO_LOADFAILED = "livemark/loadfailed";
+const LMANNO_LOADING = "livemark/loading";
 
 const PS_CONTRACTID = "@mozilla.org/preferences-service;1";
 const NH_CONTRACTID = "@mozilla.org/browser/nav-history-service;1";
@@ -404,11 +399,16 @@ const FP_CONTRACTID = "@mozilla.org/feed-processor;1";
 const SEC_CONTRACTID = "@mozilla.org/scriptsecuritymanager;1";
 const IS_CONTRACTID = "@mozilla.org/widget/idleservice;1";
 const SEC_FLAGS = Ci.nsIScriptSecurityManager.DISALLOW_INHERIT_PRINCIPAL;
-const NS_BINDING_ABORTED = 0x804b0002;
 
 // Expire livemarks after 1 hour by default
 var gExpiration = 3600000;
 
+// Number of livemarks that are read at once
+var gLimitCount = 1;
+
+// Interval when livemarks are loaded
+var gDelayTime  = 3;
+
 // Expire livemarks after 10 minutes on error
 const ERROR_EXPIRATION = 600000;
 
@@ -419,38 +419,16 @@ const IDLE_TIMELIMIT = 1800000;
 // This cap is used only if the user sets a very high expiration time (>4h)
 const MAX_REFRESH_TIME = 3600000;
 
-var gIoService = Cc[IO_CONTRACTID].getService(Ci.nsIIOService);
-var gStringBundle;
-function GetString(name)
-{
-  try {
-    if (!gStringBundle) {
-      var bundleService = Cc[SB_CONTRACTID].getService();
-      bundleService = bundleService.QueryInterface(Ci.nsIStringBundleService);
-      gStringBundle = bundleService.createBundle(PLACES_BUNDLE_URI);
-    }
-
-    if (gStringBundle)
-      return gStringBundle.GetStringFromName(name);
-  } catch (ex) {
-    LOG("Exception loading string bundle: " + ex.message);
-  }
-
-  return null;
-}
-
 function MarkLivemarkLoadFailed(aFolderId) {
-  // if it failed before, too, nothing more to do
   var ans = Cc[AS_CONTRACTID].getService(Ci.nsIAnnotationService);
+  // if it failed before, nothing more to do
   if (ans.itemHasAnnotation(aFolderId, LMANNO_LOADFAILED))
     return;
 
-  var failedMsg = GetString("bookmarksLivemarkFailed") || DEFAULT_FAIL_MSG;
-  var failedURI = gIoService.newURI("about:livemark-failed", null, null);
-  var bms = Cc[BMS_CONTRACTID].getService(Ci.nsINavBookmarksService);
-  bms.insertBookmark(aFolderId, failedURI, 0, failedMsg);
-  ans.setItemAnnotation(aFolderId, LMANNO_LOADFAILED, true, 0,
-                        ans.EXPIRE_NEVER);
+  // removeItemAnnotation can safely be used even when the anno isn't set
+  ans.removeItemAnnotation(aFolderId, LMANNO_LOADING);
+  ans.setItemAnnotation(aFolderId, LMANNO_LOADFAILED, true,
+                        0, ans.EXPIRE_NEVER);
 }
 
 function LivemarkService() {
@@ -465,28 +443,31 @@ function LivemarkService() {
   }
   catch (ex) { }
 
+  try {
+    gLimitCount = prefs.getIntPref("browser.bookmarks.livemark_refresh_limit_count");
+    if ( gLimitCount < 1 ) gLimitCount = 1;
+  }
+  catch (ex) { }
+
+  try {
+    gDelayTime = prefs.getIntPref("browser.bookmarks.livemark_refresh_delay_time");
+    if ( gDelayTime < 1 ) gDelayTime = 1;
+  }
+  catch (ex) { }
+
   // [ {folderId:, folderURI:, feedURI:, loadGroup:, locked: } ];
   this._livemarks = [];
 
-  this._loading = GetString("bookmarksLivemarkLoading") || DEFAULT_LOAD_MSG;
   this._observerServiceObserver =
     new G_ObserverServiceObserver('xpcom-shutdown',
                                   BindToObject(this._shutdown, this),
                                   true /*only once*/);
 
-  if (IS_CONTRACTID in Cc)
-    this._idleService = Cc[IS_CONTRACTID].getService(Ci.nsIIdleService);
-
-  // this is giving a reentrant getService warning in XPCShell. bug 194568.
-  this._ans = Cc[AS_CONTRACTID].getService(Ci.nsIAnnotationService);
-
   var livemarks = this._ans.getItemsWithAnnotation(LMANNO_FEEDURI, {});
   for (var i = 0; i < livemarks.length; i++) {
-    var feedURI =
-      gIoService.newURI(
-        this._ans.getItemAnnotation(livemarks[i], LMANNO_FEEDURI),
-        null, null
-      );
+    var feedURI = this._ios.newURI(this._ans.getItemAnnotation(livemarks[i],
+                                                               LMANNO_FEEDURI),
+                                   null, null);
     this._pushLivemark(livemarks[i], feedURI);
   }
 
@@ -496,15 +477,35 @@ function LivemarkService() {
 LivemarkService.prototype = {
 
   get _bms() {
-    if (!this.__bms)
-      this.__bms = Cc[BMS_CONTRACTID].getService(Ci.nsINavBookmarksService);
-    return this.__bms;
+    var svc = Cc[BMS_CONTRACTID].getService(Ci.nsINavBookmarksService);
+    this.__defineGetter__("_bms", function() svc);
+    return this._bms;
   },
 
   get _history() {
-    if (!this.__history)
-      this.__history = Cc[NH_CONTRACTID].getService(Ci.nsINavHistoryService);
-    return this.__history;
+    var svc = Cc[NH_CONTRACTID].getService(Ci.nsINavHistoryService);
+    this.__defineGetter__("_history", function() svc);
+    return this._history;
+  },
+
+  get _ans() {
+    var svc = Cc[AS_CONTRACTID].getService(Ci.nsIAnnotationService);
+    this.__defineGetter__("_ans", function() svc);
+    return this._ans;
+  },
+
+  get _ios() {
+    var svc = Cc[IO_CONTRACTID].getService(Ci.nsIIOService);
+    this.__defineGetter__("_ios", function() svc);
+    return this._ios;
+  },
+
+  get _idleService() {
+    if (!(IS_CONTRACTID in Cc))
+      return null;
+    var svc = Cc[IS_CONTRACTID].getService(Ci.nsIIdleService);
+    this.__defineGetter__("_idleService", function() svc);
+    return this._idleService;
   },
 
   _updateTimer: null,
@@ -515,16 +516,23 @@ LivemarkService.prototype = {
     // we do a first check of the livemarks here, next checks will be on timer
     // browser start => 5s => this.start() => check => refresh_time => check
     this._checkAllLivemarks();
-    // the refresh time is calculated from the expiration time, but with a cap
-    var refresh_time = Math.min(Math.floor(gExpiration / 4), MAX_REFRESH_TIME);
-    this._updateTimer = new G_Alarm(BindToObject(this._checkAllLivemarks, this),
-                                    refresh_time, true /* repeat */);
+  },
+
+  stopUpdateLivemarks: function LS_stopUpdateLivemarks() {
+    for (var livemark in this._livemarks) {
+      if (livemark.loadGroup)
+        livemark.loadGroup.cancel(Components.results.NS_BINDING_ABORTED);
+    }
+    // kill timer
+    if (this._updateTimer) {
+      this._updateTimer.cancel();
+      this._updateTimer = null;
+    }
   },
 
   _pushLivemark: function LS__pushLivemark(aFolderId, aFeedURI) {
     // returns new length of _livemarks
-    return this._livemarks.push({folderId: aFolderId, feedURI: aFeedURI,
-                                 loadingId: -1});
+    return this._livemarks.push({folderId: aFolderId, feedURI: aFeedURI});
   },
 
   _getLivemarkIndex: function LS__getLivemarkIndex(aFolderId) {
@@ -539,22 +547,34 @@ LivemarkService.prototype = {
     // remove bookmarks observer
     this._bms.removeObserver(this);
 
-    for (var livemark in this._livemarks) {
-      if (livemark.loadGroup)
-        livemark.loadGroup.cancel(NS_BINDING_ABORTED);
-    }
-
-    // kill timer
-    if (this._updateTimer) {
-      this._updateTimer.cancel();
-      this._updateTimer = null;
-    }
+    // stop to update livemarks
+    this.stopUpdateLivemarks();
   },
 
+  // We try to distribute the load of the livemark update.
+  // load gLimitCount Livemarks per gDelayTime sec.
+  _nextUpdateStartIndex : 0,
   _checkAllLivemarks: function LS__checkAllLivemarks() {
-    // check if livemarks are expired, update if needed
-    for (var i = 0; i < this._livemarks.length; ++i) {
-      this._updateLivemarkChildren(i, false);
+    var startNo = this._nextUpdateStartIndex;
+    var count = 0;
+    for (var i = startNo; (i < this._livemarks.length) && (count < gLimitCount); ++i ) {
+      // check if livemarks are expired, update if needed
+      try {
+        if (this._updateLivemarkChildren(i, false)) count++;
+      }
+      catch (ex) { }
+      this._nextUpdateStartIndex = i+1;
+    }
+    if ( this._nextUpdateStartIndex >= this._livemarks.length ) {
+      // all livemarks are checked, sleeping until next period
+      this._nextUpdateStartIndex = 0;
+      var refresh_time = Math.min(Math.floor(gExpiration / 4), MAX_REFRESH_TIME);
+      this._updateTimer = new G_Alarm(BindToObject(this._checkAllLivemarks, this),
+                                      refresh_time);
+    } else {
+      // wait gDelayTime sec.
+      this._updateTimer = new G_Alarm(BindToObject(this._checkAllLivemarks, this),
+                                      gDelayTime*1000);
     }
   },
 
@@ -562,13 +582,6 @@ LivemarkService.prototype = {
     this._bms.removeFolderChildren(aFolderId);
   },
 
-  insertLivemarkLoadingItem: function LS_insertLivemarkLoading(aBms, aLivemark) {
-    var loadingURI = gIoService.newURI("about:livemark-loading", null, null);
-    if (!aLivemark.loadingId || aLivemark.loadingId == -1)
-      aLivemark.loadingId = aBms.insertBookmark(aLivemark.folderId, loadingURI,
-                                              0, this._loading);
-  },
-
   _updateLivemarkChildren:
   function LS__updateLivemarkChildren(aIndex, aForceUpdate) {
     if (this._livemarks[aIndex].locked)
@@ -613,7 +626,7 @@ LivemarkService.prototype = {
       // automatically keep track of redirects, so we can always
       // cancel the channel.
       loadgroup = Cc[LG_CONTRACTID].createInstance(Ci.nsILoadGroup);
-      var uriChannel = gIoService.newChannel(livemark.feedURI.spec, null, null);
+      var uriChannel = this._ios.newChannel(livemark.feedURI.spec, null, null);
       uriChannel.loadGroup = loadgroup;
       uriChannel.loadFlags |= Ci.nsIRequest.LOAD_BACKGROUND |
                               Ci.nsIRequest.VALIDATE_ALWAYS;
@@ -623,15 +636,14 @@ LivemarkService.prototype = {
 
       // Stream the result to the feed parser with this listener
       var listener = new LivemarkLoadListener(livemark);
-      this.insertLivemarkLoadingItem(this._bms, livemark);
+      // removeItemAnnotation can safely be used even when the anno isn't set
+      this._ans.removeItemAnnotation(livemark.folderId, LMANNO_LOADFAILED);
+      this._ans.setItemAnnotation(livemark.folderId, LMANNO_LOADING, true,
+                                  0, this._ans.EXPIRE_NEVER);
       httpChannel.notificationCallbacks = listener;
       httpChannel.asyncOpen(listener, null);
     }
     catch (ex) {
-      if (livemark.loadingId != -1) {
-        this._bms.removeItem(livemark.loadingId);
-        livemark.loadingId = -1;
-      }
       MarkLivemarkLoadFailed(livemark.folderId);
       livemark.locked = false;
       return false;
@@ -642,6 +654,9 @@ LivemarkService.prototype = {
 
   createLivemark: function LS_createLivemark(aParentId, aName, aSiteURI,
                                              aFeedURI, aIndex) {
+    if (!aParentId || !aFeedURI)
+      throw Cr.NS_ERROR_INVALID_ARG;
+
     // Don't add livemarks to livemarks
     if (this.isLivemark(aParentId))
       throw Cr.NS_ERROR_INVALID_ARG;
@@ -659,6 +674,9 @@ LivemarkService.prototype = {
   createLivemarkFolderOnly:
   function LS_createLivemarkFolderOnly(aParentId, aName, aSiteURI,
                                        aFeedURI, aIndex) {
+    if (aParentId < 1 || !aFeedURI)
+      throw Cr.NS_ERROR_INVALID_ARG;
+
     // Don't add livemarks to livemarks
     if (this.isLivemark(aParentId))
       throw Cr.NS_ERROR_INVALID_ARG;
@@ -668,8 +686,6 @@ LivemarkService.prototype = {
 
     var livemarkIndex = this._pushLivemark(folderId, aFeedURI) - 1;
     var livemark = this._livemarks[livemarkIndex];
-    this.insertLivemarkLoadingItem(this._bms, livemark);
-
     return folderId;
   },
 
@@ -679,8 +695,8 @@ LivemarkService.prototype = {
     this._bms.setFolderReadonly(folderId, true);
 
     // Add an annotation to map the folder id to the livemark feed URI
-    this._ans.setItemAnnotation(folderId, LMANNO_FEEDURI, aFeedURI.spec, 0,
-                                this._ans.EXPIRE_NEVER);
+    this._ans.setItemAnnotation(folderId, LMANNO_FEEDURI, aFeedURI.spec,
+                                0, this._ans.EXPIRE_NEVER);
 
     if (aSiteURI) {
       // Add an annotation to map the folder URI to the livemark site URI
@@ -691,7 +707,26 @@ LivemarkService.prototype = {
   },
 
   isLivemark: function LS_isLivemark(aFolderId) {
-    return this._ans.itemHasAnnotation(aFolderId, LMANNO_FEEDURI);
+    if (aFolderId < 1)
+      throw Cr.NS_ERROR_INVALID_ARG;
+    try {
+      this._getLivemarkIndex(aFolderId);
+      return true;
+    }
+    catch (ex) {}
+    return false;
+  },
+
+  getLivemarkIdForFeedURI: function LS_getLivemarkIdForFeedURI(aFeedURI) {
+    if (!(aFeedURI instanceof Ci.nsIURI))
+      throw Cr.NS_ERROR_INVALID_ARG;
+
+    for (var i = 0; i < this._livemarks.length; ++i) {
+      if (this._livemarks[i].feedURI.equals(aFeedURI))
+        return this._livemarks[i].folderId;
+    }
+
+    return -1;
   },
 
   _ensureLivemark: function LS__ensureLivemark(aFolderId) {
@@ -706,7 +741,7 @@ LivemarkService.prototype = {
       var siteURIString =
         this._ans.getItemAnnotation(aFolderId, LMANNO_SITEURI);
 
-      return gIoService.newURI(siteURIString, null, null);
+      return this._ios.newURI(siteURIString, null, null);
     }
     return null;
   },
@@ -740,9 +775,9 @@ LivemarkService.prototype = {
 
   getFeedURI: function LS_getFeedURI(aFolderId) {
     if (this._ans.itemHasAnnotation(aFolderId, LMANNO_FEEDURI))
-      return gIoService.newURI(this._ans.getItemAnnotation(aFolderId,
-                                                           LMANNO_FEEDURI),
-                               null, null);
+      return this._ios.newURI(this._ans.getItemAnnotation(aFolderId,
+                                                          LMANNO_FEEDURI),
+                              null, null);
     return null;
   },
 
@@ -776,8 +811,9 @@ LivemarkService.prototype = {
   onItemChanged: function() { },
   onItemVisited: function() { },
   onItemMoved: function() { },
+  onBeforeItemRemoved: function() { },
 
-  onItemRemoved: function(aItemId, aParentId, aIndex) {
+  onItemRemoved: function(aItemId, aParentId, aIndex, aItemType) {
     // we don't need to remove annotations since itemAnnotations
     // are already removed with the bookmark
     try {
@@ -793,7 +829,7 @@ LivemarkService.prototype = {
     this._livemarks.splice(livemarkIndex, 1);
 
     if (livemark.loadGroup)
-      livemark.loadGroup.cancel(NS_BINDING_ABORTED);
+      livemark.loadGroup.cancel(Components.results.NS_BINDING_ABORTED);
   },
 
   createInstance: function LS_createInstance(aOuter, aIID) {
@@ -808,17 +844,15 @@ LivemarkService.prototype = {
         aIID.equals(Ci.nsINavBookmarkObserver) ||
         aIID.equals(Ci.nsISupports))
       return this;
-    throw Cr.NS_ERROR_NOT_IMPLEMENTED;
+    throw Cr.NS_ERROR_NO_INTERFACE;
   }
 };
 
 function LivemarkLoadListener(aLivemark) {
   this._livemark = aLivemark;
-  this._livemark.loadingId = -1;
   this._processor = null;
   this._isAborted = false;
   this._ttl = gExpiration;
-  this._ans = Cc[AS_CONTRACTID].getService(Ci.nsIAnnotationService);
 }
 
 LivemarkLoadListener.prototype = {
@@ -839,6 +873,12 @@ LivemarkLoadListener.prototype = {
     return this.__history;
   },
 
+  get _ans() {
+    if (!this.__ans)
+      this.__ans = Cc[AS_CONTRACTID].getService(Ci.nsIAnnotationService);
+    return this.__ans;
+  },
+
   // called back from handleResult
   runBatched: function LLL_runBatched(aUserData) {
     var result = aUserData.QueryInterface(Ci.nsIFeedResult);
@@ -851,10 +891,6 @@ LivemarkLoadListener.prototype = {
 
     // Enforce well-formedness because the existing code does
     if (!result || !result.doc || result.bozo) {
-      if (this._livemark.loadingId != -1) {
-        this._bms.removeItem(this._livemark.loadingId);
-        this._livemark.loadingId = -1;
-      }
       MarkLivemarkLoadFailed(this._livemark.folderId);
       this._ttl = gExpiration;
       throw Cr.NS_ERROR_FAILURE;
@@ -863,9 +899,6 @@ LivemarkLoadListener.prototype = {
     // Clear out any child nodes of the livemark folder, since
     // they're about to be replaced.
     this.deleteLivemarkChildren(this._livemark.folderId);
-    this._livemark.loadingId = -1;
-    // removeItemAnnotation can safely be used even when the anno isn't set
-    this._ans.removeItemAnnotation(this._livemark.folderId, LMANNO_LOADFAILED);
     var feed = result.doc.QueryInterface(Ci.nsIFeed);
     if (feed.link) {
       var oldSiteURI = lmService.getSiteURI(this._livemark.folderId);
@@ -880,9 +913,7 @@ LivemarkLoadListener.prototype = {
       if (!href)
         continue;
 
-      let title = entry.title ? entry.title.plainText() : entry.updated;
-      if (!title)
-        continue;
+      let title = entry.title ? entry.title.plainText() : "";
 
       try {
         secMan.checkLoadURIWithPrincipal(feedPrincipal, href, SEC_FLAGS);
@@ -900,10 +931,6 @@ LivemarkLoadListener.prototype = {
    */
   handleResult: function LLL_handleResult(aResult) {
     if (this._isAborted) {
-      if (this._livemark.loadingId != -1) {
-        this._bms.removeItem(this._livemark.loadingId);
-        this._livemark.loadingId = -1;
-      }
       MarkLivemarkLoadFailed(this._livemark.folderId);
       this._livemark.locked = false;
       return;
@@ -916,6 +943,7 @@ LivemarkLoadListener.prototype = {
       this._processor.listener = null;
       this._processor = null;
       this._livemark.locked = false;
+      this._ans.removeItemAnnotation(this._livemark.folderId, LMANNO_LOADING);
     }
   },
 
@@ -931,8 +959,9 @@ LivemarkLoadListener.prototype = {
    */
   onDataAvailable: function LLL_onDataAvailable(aRequest, aContext, aInputStream,
                                                 aSourceOffset, aCount) {
-    this._processor.onDataAvailable(aRequest, aContext, aInputStream,
-                                    aSourceOffset, aCount);
+    if (this._processor)
+      this._processor.onDataAvailable(aRequest, aContext, aInputStream,
+                                      aSourceOffset, aCount);
   },
 
   /**
@@ -949,7 +978,12 @@ LivemarkLoadListener.prototype = {
     this._processor.listener = this;
     this._processor.parseAsync(null, channel.URI);
 
-    this._processor.onStartRequest(aRequest, aContext);
+    try {
+      this._processor.onStartRequest(aRequest, aContext);
+    }
+    catch (ex) {
+      Components.utils.reportError("Livemark Service: feed processor received an invalid channel for " + channel.URI.spec);
+    }
   },
 
   /**
@@ -957,20 +991,22 @@ LivemarkLoadListener.prototype = {
    */
   onStopRequest: function LLL_onStopRequest(aRequest, aContext, aStatus) {
     if (!Components.isSuccessCode(aStatus)) {
-      // Something went wrong, try to load again in a bit
-      this._setResourceTTL(ERROR_EXPIRATION);
       this._isAborted = true;
-      if (this._livemark.loadingId != -1) {
-        this._bms.removeItem(this._livemark.loadingId);
-        this._livemark.loadingId = -1;
-      }
-      MarkLivemarkLoadFailed(this._livemark.folderId);
       this._livemark.locked = false;
+      var lmService = Cc[LS_CONTRACTID].getService(Ci.nsILivemarkService);
+      // One of the reasons we could abort a request is when a livemark is
+      // removed, in such a case the livemark itemId would already be invalid.
+      if (lmService.isLivemark(this._livemark.folderId)) {
+        // Something went wrong, try to load again in a bit
+        this._setResourceTTL(ERROR_EXPIRATION);
+        MarkLivemarkLoadFailed(this._livemark.folderId);
+      }
       return;
     }
     // Set an expiration on the livemark, for reloading the data
     try {
-      this._processor.onStopRequest(aRequest, aContext, aStatus);
+      if (this._processor)
+        this._processor.onStopRequest(aRequest, aContext, aStatus);
 
       // Calculate a new ttl
       var channel = aRequest.QueryInterface(Ci.nsICachingChannel);
