@@ -1,12 +1,12 @@
-//@line 37 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 37 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 
 // XXX Toolkit-specific preferences should be moved into toolkit.js
 
-//@line 41 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 41 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 
-//@line 44 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 44 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 
-//@line 50 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 50 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 
 pref("general.startup.browser", true);
 
@@ -30,24 +30,35 @@ pref("extensions.hideInstallButton", true);
 
 // Preferences for the Get Add-ons pane
 pref("extensions.getAddons.showPane", true);
-pref("extensions.getAddons.browseAddons", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%");
+pref("extensions.getAddons.browseAddons", "https://addons.mozilla.org/%LOCALE%/%APP%");
 pref("extensions.getAddons.maxResults", 5);
-pref("extensions.getAddons.recommended.browseURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/recommended");
+pref("extensions.getAddons.recommended.browseURL", "https://addons.mozilla.org/%LOCALE%/%APP%/recommended");
 pref("extensions.getAddons.recommended.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/list/featured/all/10/%OS%/%VERSION%");
-pref("extensions.getAddons.search.browseURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/search?q=%TERMS%");
+pref("extensions.getAddons.search.browseURL", "https://addons.mozilla.org/%LOCALE%/%APP%/search?q=%TERMS%");
 pref("extensions.getAddons.search.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/search/%TERMS%/all/10/%OS%/%VERSION%");
 
 // Blocklist preferences
 pref("extensions.blocklist.enabled", true);
 pref("extensions.blocklist.interval", 86400);
+// Controls what level the blocklist switches from warning about items to forcibly
+// blocking them.
+pref("extensions.blocklist.level", 2);
 pref("extensions.blocklist.url", "https://addons.mozilla.org/blocklist/3/%APP_ID%/%APP_VERSION%/%PRODUCT%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/");
-pref("extensions.blocklist.detailsURL", "http://%LOCALE%.www.mozilla.com/%LOCALE%/blocklist/");
+pref("extensions.blocklist.detailsURL", "https://www.mozilla.com/%LOCALE%/blocklist/");
 
 // Dictionary download preference
-pref("browser.dictionaries.download.url", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/firefox/%VERSION%/dictionaries/");
+pref("browser.dictionaries.download.url", "https://addons.mozilla.org/%LOCALE%/%APP%/dictionaries/");
+
+// Update Timer Manager preferences
+// Interval: When all registered timers should be checked (in milliseconds)
+//           default=10 minutes
+pref("app.update.timer", 600000);
 
 // App-specific update preferences
 
+// The interval to check for updates (app.update.interval) is defined in
+// firefox-branding.js
+
 // Whether or not app updates are enabled
 pref("app.update.enabled", false);
 
@@ -78,16 +89,13 @@ pref("app.update.url", "https://aus2.mozilla.org/update/3/%PRODUCT%/%VERSION%/%B
 // User-settable override to app.update.url for testing purposes.
 //pref("app.update.url.override", "");
 
-// Interval: Time between checks for a new version (in seconds)
-//           default=1 day
-pref("app.update.interval", 86400);
+// app.update.interval is in branding section
+
 // Interval: Time before prompting the user again to restart to install the
 //           latest download (in seconds) default=1 day
 pref("app.update.nagTimer.restart", 86400);
-// Interval: When all registered timers should be checked (in milliseconds)
-//           default=10 minutes
-pref("app.update.timer", 600000);
-// Give the user x seconds to react before showing the big UI. default=12 hrs
+
+// Give the user x seconds to react before showing the big UI. default=12 hours
 pref("app.update.promptWaitTime", 43200);
 // Show the Update Checking/Ready UI when the user was idle for x seconds
 pref("app.update.idletime", 60);
@@ -110,35 +118,37 @@ pref("app.update.incompatible.mode", 0);
 // e.g.
 //  extensions.{GUID}.update.enabled
 //  extensions.{GUID}.update.url
-//  extensions.{GUID}.update.interval
 //  .. etc ..
 //
 pref("extensions.update.enabled", true);
-pref("extensions.update.url", "https://versioncheck.addons.mozilla.org/update/VersionCheck.php?reqVersion=%REQ_VERSION%&id=%ITEM_ID%&version=%ITEM_VERSION%&maxAppVersion=%ITEM_MAXAPPVERSION%&status=%ITEM_STATUS%&appID=%APP_ID%&appVersion=%APP_VERSION%&appOS=%APP_OS%&appABI=%APP_ABI%&locale=%APP_LOCALE%");
+pref("extensions.update.url", "https://versioncheck.addons.mozilla.org/update/VersionCheck.php?reqVersion=%REQ_VERSION%&id=%ITEM_ID%&version=%ITEM_VERSION%&maxAppVersion=%ITEM_MAXAPPVERSION%&status=%ITEM_STATUS%&appID=%APP_ID%&appVersion=%APP_VERSION%&appOS=%APP_OS%&appABI=%APP_ABI%&locale=%APP_LOCALE%&currentAppVersion=%CURRENT_APP_VERSION%&updateType=%UPDATE_TYPE%");
 pref("extensions.update.interval", 86400);  // Check for updates to Extensions and 
                                             // Themes every day
 // Non-symmetric (not shared by extensions) extension-specific [update] preferences
-pref("extensions.getMoreExtensionsURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/%VERSION%/extensions/");
-pref("extensions.getMoreThemesURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/%VERSION%/themes/");
-pref("extensions.getMorePluginsURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/%VERSION%/plugins/");
+pref("extensions.getMoreThemesURL", "https://addons.mozilla.org/%LOCALE%/%APP%/getpersonas");
 pref("extensions.dss.enabled", false);          // Dynamic Skin Switching                                               
 pref("extensions.dss.switchPending", false);    // Non-dynamic switch pending after next
                                                 // restart.
 
-pref("xpinstall.whitelist.add", "update.mozilla.org");
-pref("xpinstall.whitelist.add.103", "addons.mozilla.org");
+pref("extensions.{972ce4c6-7e08-4474-a285-3208198ce6fd}.name", "chrome://browser/locale/browser.properties");
+pref("extensions.{972ce4c6-7e08-4474-a285-3208198ce6fd}.description", "chrome://browser/locale/browser.properties");
+
+pref("xpinstall.whitelist.add", "addons.mozilla.org");
+pref("xpinstall.whitelist.add.36", "getpersonas.com");
+
+pref("lightweightThemes.update.enabled", true);
 
 pref("keyword.enabled", true);
 pref("keyword.URL", "chrome://browser-region/locale/region.properties");
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
-pref("general.useragent.extra.firefox", "Firefox/3.0.18");
+pref("general.useragent.extra.firefox", "Firefox/3.6.8");
 
 pref("general.smoothScroll", false);
-//@line 180 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 190 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("general.autoScroll", false);
-//@line 184 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 194 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 
 // Whether or not the application should check at startup each time if it 
 // is the default browser.
@@ -149,36 +159,51 @@ pref("browser.shell.checkDefaultBrowser", true);
 pref("browser.startup.page",                1);
 pref("browser.startup.homepage",            "resource:/browserconfig.properties");
 
-pref("browser.cache.disk.capacity",         50000);
 pref("browser.enable_automatic_image_resizing", true);
 pref("browser.chrome.site_icons", true);
 pref("browser.chrome.favicons", true);
-pref("browser.formfill.enable", true);
 pref("browser.warnOnQuit", true);
 pref("browser.warnOnRestart", true);
 pref("browser.fullscreen.autohide", true);
 pref("browser.fullscreen.animateUp", 1);
 
-//@line 205 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 213 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("browser.urlbar.clickSelectsAll", false);
-//@line 210 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 218 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("browser.urlbar.doubleClickSelectsAll", true);
-//@line 214 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 222 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("browser.urlbar.autoFill", false);
-pref("browser.urlbar.matchOnlyTyped", false);
 // 0: Match anywhere (e.g., middle of words)
 // 1: Match on word boundaries and then try matching anywhere
 // 2: Match only on word boundaries (e.g., after / or .)
+// 3: Match at the beginning of the url or title
 pref("browser.urlbar.matchBehavior", 1);
 pref("browser.urlbar.filter.javascript", true);
 
 // the maximum number of results to show in autocomplete when doing richResults
 pref("browser.urlbar.maxRichResults", 12);
-// Size of "chunks" affects the number of places to process between each search
-// timeout (ms). Too big and the UI will be unresponsive; too small and we'll
-// be waiting on the timeout too often without many results.
-pref("browser.urlbar.search.chunkSize", 1000);
-pref("browser.urlbar.search.timeout", 100);
+// The amount of time (ms) to wait after the user has stopped typing
+// before starting to perform autocomplete.  50 is the default set in
+// autocomplete.xml.
+pref("browser.urlbar.delay", 50);
+
+// The special characters below can be typed into the urlbar to either restrict
+// the search to visited history, bookmarked, tagged pages; or force a match on
+// just the title text or url.
+pref("browser.urlbar.restrict.history", "^");
+pref("browser.urlbar.restrict.bookmark", "*");
+pref("browser.urlbar.restrict.tag", "+");
+pref("browser.urlbar.restrict.typed", "~");
+pref("browser.urlbar.match.title", "#");
+pref("browser.urlbar.match.url", "@");
+
+// The default behavior for the urlbar can be configured to use any combination
+// of the restrict or match filters with each additional filter restricting
+// more (intersection). Add the following values to set the behavior as the
+// default: 1: history, 2: bookmark, 4: tag, 8: title, 16: url, 32: typed
+// E.g., 0 = show all results (no filtering), 1 = only visited pages in history,
+// 2 = only bookmarks, 3 = visited bookmarks, 1+16 = history matching in the url
+pref("browser.urlbar.default.behavior", 0);
 
 // Number of milliseconds to wait for the http headers (and thus
 // the Content-Disposition filename) before giving up and falling back to 
@@ -187,14 +212,15 @@ pref("browser.urlbar.search.timeout", 100);
 pref("browser.download.saveLinkAsFilenameTimeout", 1000);
 
 pref("browser.download.useDownloadDir", true);
-pref("browser.download.folderList", 0);
+
+//@line 267 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
+pref("browser.download.folderList", 1);
+//@line 269 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("browser.download.manager.showAlertOnComplete", true);
 pref("browser.download.manager.showAlertInterval", 2000);
 pref("browser.download.manager.retention", 2);
 pref("browser.download.manager.showWhenStarting", true);
-pref("browser.download.manager.useWindow", true);
 pref("browser.download.manager.closeWhenDone", false);
-pref("browser.download.manager.openDelay", 0);
 pref("browser.download.manager.focusWhenStarting", false);
 pref("browser.download.manager.flashCount", 2);
 pref("browser.download.manager.addToRecentDocs", true);
@@ -203,7 +229,7 @@ pref("browser.download.manager.scanWhenDone", true);
 pref("browser.download.manager.resumeOnWakeDelay", 10000);
 
 // search engines URL
-pref("browser.search.searchEnginesURL",      "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/firefox/%VERSION%/search-engines/");
+pref("browser.search.searchEnginesURL",      "https://addons.mozilla.org/%LOCALE%/%APP%/search-engines/");
 
 // pointer to the default engine name
 pref("browser.search.defaultenginename",      "chrome://browser-region/locale/region.properties");
@@ -234,18 +260,16 @@ pref("browser.microsummary.updateGenerators", true);
 // enable search suggestions by default
 pref("browser.search.suggest.enabled", true);
 
-pref("browser.history.grouping", "day");
 pref("browser.history.showSessions", false);
 pref("browser.sessionhistory.max_entries", 50);
+//@line 316 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("browser.history_expire_days", 180);
 pref("browser.history_expire_days_min", 90);
+//@line 322 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("browser.history_expire_sites", 40000);
 
-// handle external links
-// 0=default window, 1=current window/tab, 2=new window, 3=new tab in most recent window
-pref("browser.link.open_external", 3);
-
 // handle links targeting new windows
+// 0=default window, 1=current window/tab, 2=new window, 3=new tab in most recent window
 pref("browser.link.open_newwindow", 3);
 
 // 0: no restrictions - divert everything
@@ -254,8 +278,11 @@ pref("browser.link.open_newwindow", 3);
 pref("browser.link.open_newwindow.restriction", 2);
 
 // Tabbed browser
-pref("browser.tabs.autoHide", true);
-pref("browser.tabs.forceHide", false);
+//@line 335 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
+pref("browser.tabs.autoHide", false);
+//@line 339 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
+pref("browser.tabs.closeWindowWithLastTab", true);
+pref("browser.tabs.insertRelatedAfterCurrent", true);
 pref("browser.tabs.warnOnClose", true);
 pref("browser.tabs.warnOnOpen", true);
 pref("browser.tabs.maxOpenBeforeWarn", 15);
@@ -282,6 +309,10 @@ pref("browser.tabs.closeButtons", 1);
 // false  return to the adjacent tab (old default)
 pref("browser.tabs.selectOwnerOnClose", true);
 
+pref("browser.allTabs.previews", false);
+pref("browser.ctrlTab.previews", false);
+pref("browser.ctrlTab.recentlyUsedLimit", 7);
+
 // Default bookmark sorting
 pref("browser.bookmarks.sort.direction", "descending");
 pref("browser.bookmarks.sort.resource", "rdf:http://home.netscape.com/NC-rdf#Name");
@@ -299,9 +330,11 @@ pref("browser.bookmarks.max_backups",             5);
 
 // Scripts & Windows prefs
 pref("dom.disable_open_during_load",              true);
-//@line 353 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 392 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("javascript.options.showInConsole",          false);
-//@line 355 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 394 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
+
+//@line 399 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 
 // Make the status bar reliably present and unaffected by pages
 pref("dom.disable_window_open_feature.status",    true);
@@ -322,19 +355,39 @@ pref("privacy.popups.policy",               1);
 pref("privacy.popups.usecustom",            true);
 pref("privacy.popups.firstTime",            true);
 pref("privacy.popups.showBrowserMessage",   true);
- 
-pref("privacy.item.history",     true);
-pref("privacy.item.formdata",    true);
-pref("privacy.item.passwords",   false);
-pref("privacy.item.downloads",   true);
-pref("privacy.item.cookies",     false);
-pref("privacy.item.cache",       true);
-pref("privacy.item.siteprefs",   false);
-pref("privacy.item.sessions",    true);
-pref("privacy.item.offlineApps", false);
 
+pref("privacy.item.cookies",                false);
+
+pref("privacy.clearOnShutdown.history",     true);
+pref("privacy.clearOnShutdown.formdata",    true);
+pref("privacy.clearOnShutdown.passwords",   false);
+pref("privacy.clearOnShutdown.downloads",   true);
+pref("privacy.clearOnShutdown.cookies",     true);
+pref("privacy.clearOnShutdown.cache",       true);
+pref("privacy.clearOnShutdown.sessions",    true);
+pref("privacy.clearOnShutdown.offlineApps", false);
+pref("privacy.clearOnShutdown.siteSettings", false);
+
+pref("privacy.cpd.history",                 true);
+pref("privacy.cpd.formdata",                true);
+pref("privacy.cpd.passwords",               false);
+pref("privacy.cpd.downloads",               true);
+pref("privacy.cpd.cookies",                 true);
+pref("privacy.cpd.cache",                   true);
+pref("privacy.cpd.sessions",                true);
+pref("privacy.cpd.offlineApps",             false);
+pref("privacy.cpd.siteSettings",            false);
+
+// What default should we use for the time span in the sanitizer:
+// 0 - Clear everything
+// 1 - Last Hour
+// 2 - Last 2 Hours
+// 3 - Last 4 Hours
+// 4 - Today
+pref("privacy.sanitize.timeSpan", 1);
 pref("privacy.sanitize.sanitizeOnShutdown", false);
-pref("privacy.sanitize.promptOnSanitize", true);
+
+pref("privacy.sanitize.migrateFx3Prefs",    false);
 
 pref("network.proxy.share_proxy_settings",  false); // use the same proxy settings for all protocols
 
@@ -348,15 +401,34 @@ pref("intl.charsetmenu.browser.more2",  "chrome://global/locale/intl.properties"
 pref("intl.charsetmenu.browser.more3",  "chrome://global/locale/intl.properties");
 pref("intl.charsetmenu.browser.more4",  "chrome://global/locale/intl.properties");
 pref("intl.charsetmenu.browser.more5",  "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.unicode",  "chrome://global/locale/intl.properties");
+pref("intl.charsetmenu.browser.unicode",  "UTF-8, UTF-16LE, UTF-16BE, UTF-32, UTF-32LE, UTF-32BE");
 pref("intl.charset.detector", "chrome://global/locale/intl.properties");
 pref("intl.charset.default",  "chrome://global-platform/locale/intl.properties");
 pref("font.language.group", "chrome://global/locale/intl.properties");
 pref("intl.menuitems.alwaysappendaccesskeys","chrome://global/locale/intl.properties");
 pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/intl.properties");
 
+// simple gestures support
+pref("browser.gesture.swipe.left", "Browser:BackOrBackDuplicate");
+pref("browser.gesture.swipe.right", "Browser:ForwardOrForwardDuplicate");
+pref("browser.gesture.swipe.up", "cmd_scrollTop");
+pref("browser.gesture.swipe.down", "cmd_scrollBottom");
+//@line 481 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
+pref("browser.gesture.pinch.latched", false);
+pref("browser.gesture.pinch.threshold", 25);
+//@line 484 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
+pref("browser.gesture.pinch.out", "cmd_fullZoomEnlarge");
+pref("browser.gesture.pinch.in", "cmd_fullZoomReduce");
+pref("browser.gesture.pinch.out.shift", "cmd_fullZoomReset");
+pref("browser.gesture.pinch.in.shift", "cmd_fullZoomReset");
+pref("browser.gesture.twist.latched", false);
+pref("browser.gesture.twist.threshold", 25);
+pref("browser.gesture.twist.right", "");
+pref("browser.gesture.twist.left", "");
+pref("browser.gesture.tap", "cmd_fullZoomReset");
+
 // 0=lines, 1=pages, 2=history , 3=text size
-//@line 423 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 509 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("mousewheel.withshiftkey.action",2);
 pref("mousewheel.withshiftkey.sysnumlines",false);
 pref("mousewheel.withshiftkey.numlines",1);
@@ -366,7 +438,7 @@ pref("mousewheel.withaltkey.numlines",1);
 pref("mousewheel.withmetakey.action",0);
 pref("mousewheel.withmetakey.sysnumlines",true);
 pref("mousewheel.withmetakey.numlines",1);
-//@line 433 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 519 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("mousewheel.withcontrolkey.action",3);
 pref("mousewheel.withcontrolkey.sysnumlines",false);
 pref("mousewheel.withcontrolkey.numlines",1);
@@ -423,29 +495,29 @@ pref("plugin.default_plugin_disabled", true);
 // plugin finder service url
 pref("pfs.datasource.url", "https://pfs.mozilla.org/plugins/PluginFinderService.php?mimetype=%PLUGIN_MIMETYPE%&appID=%APP_ID%&appVersion=%APP_VERSION%&clientOS=%CLIENT_OS%&chromeLocale=%CHROME_LOCALE%&appRelease=%APP_RELEASE%");
 
-// by default we show an infobar message when pages require plugins the user has not installed
-pref("plugins.hide_infobar_for_missing_plugin", false);
+// by default we show an infobar message when pages require plugins the user has not installed, or are outdated
+pref("plugins.hide_infobar_for_missing_plugin", true);
+pref("plugins.hide_infobar_for_outdated_plugin", false);
 
-//@line 495 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+pref("plugins.update.url", "https://www.mozilla.com/%LOCALE%/plugincheck/");
+pref("plugins.update.notifyUser", false);
+
+//@line 585 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("browser.preferences.instantApply", true);
-//@line 500 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 590 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 502 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 592 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 
 pref("browser.download.show_plugins_in_list", true);
 pref("browser.download.hide_plugins_without_extensions", true);
 
-// Setting this pref to |true| forces BiDi UI menu items and keyboard shortcuts
-// to be exposed. By default, only expose it for bidi-associated system locales.
-pref("bidi.browser.ui", false);
-
 // Backspace and Shift+Backspace behavior
 // 0 goes Back/Forward
 // 1 act like PgUp/PgDown
 // 2 and other values, nothing
-//@line 515 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 601 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("browser.backspace_action", 2);
-//@line 519 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 605 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 
 // this will automatically enable inline spellchecking (if it is available) for
 // editable elements in HTML
@@ -454,9 +526,6 @@ pref("browser.backspace_action", 2);
 // 2 = check multi/single line controls
 pref("layout.spellcheckDefault", 1);
 
-pref("view_source.editor.path", "");
-pref("view_source.editor.external", false);
-
 pref("browser.send_pings", false);
 
 /* initial web feed readers list */
@@ -514,11 +583,30 @@ pref("gecko.handlerService.schemes.mailto.2.uriTemplate", "chrome://browser-regi
 pref("gecko.handlerService.schemes.mailto.3.name", "chrome://browser-region/locale/region.properties");
 pref("gecko.handlerService.schemes.mailto.3.uriTemplate", "chrome://browser-region/locale/region.properties");
 
+// irc
+pref("gecko.handlerService.schemes.irc.0.name", "chrome://browser-region/locale/region.properties");
+pref("gecko.handlerService.schemes.irc.0.uriTemplate", "chrome://browser-region/locale/region.properties");
+pref("gecko.handlerService.schemes.irc.1.name", "chrome://browser-region/locale/region.properties");
+pref("gecko.handlerService.schemes.irc.1.uriTemplate", "chrome://browser-region/locale/region.properties");
+pref("gecko.handlerService.schemes.irc.2.name", "chrome://browser-region/locale/region.properties");
+pref("gecko.handlerService.schemes.irc.2.uriTemplate", "chrome://browser-region/locale/region.properties");
+pref("gecko.handlerService.schemes.irc.3.name", "chrome://browser-region/locale/region.properties");
+pref("gecko.handlerService.schemes.irc.3.uriTemplate", "chrome://browser-region/locale/region.properties");
+
+// ircs
+pref("gecko.handlerService.schemes.ircs.0.name", "chrome://browser-region/locale/region.properties");
+pref("gecko.handlerService.schemes.ircs.0.uriTemplate", "chrome://browser-region/locale/region.properties");
+pref("gecko.handlerService.schemes.ircs.1.name", "chrome://browser-region/locale/region.properties");
+pref("gecko.handlerService.schemes.ircs.1.uriTemplate", "chrome://browser-region/locale/region.properties");
+pref("gecko.handlerService.schemes.ircs.2.name", "chrome://browser-region/locale/region.properties");
+pref("gecko.handlerService.schemes.ircs.2.uriTemplate", "chrome://browser-region/locale/region.properties");
+pref("gecko.handlerService.schemes.ircs.3.name", "chrome://browser-region/locale/region.properties");
+pref("gecko.handlerService.schemes.ircs.3.uriTemplate", "chrome://browser-region/locale/region.properties");
 
 // By default, we don't want protocol/content handlers to be registered from a different host, see bug 402287
 pref("gecko.handlerService.allowRegisterFromDifferentHost", false);
 
-//@line 592 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 694 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 // Safe browsing does nothing unless this pref is set
 pref("browser.safebrowsing.enabled", false);
 
@@ -537,18 +625,16 @@ pref("browser.safebrowsing.provider.0.keyURL", "https://sb-ssl.google.com/safebr
 pref("browser.safebrowsing.provider.0.reportURL", "http://safebrowsing.clients.google.com/safebrowsing/report?");
 pref("browser.safebrowsing.provider.0.gethashURL", "http://safebrowsing.clients.google.com/safebrowsing/gethash?client={moz:client}&appver={moz:version}&pver=2.2");
 
-// privacy policy -- Both url and fallbackurl must exist, although they may
-// point to the same file.  fallbackurl must be a chrome url
-pref("browser.safebrowsing.provider.0.privacy.url", "http://www.google.com/tools/firefox/firefox_privacy.html?hl=%LOCALE%");
-pref("browser.safebrowsing.provider.0.privacy.fallbackurl", "chrome://browser/content/preferences/phishEULA.xhtml");
-
 // HTML report pages
 pref("browser.safebrowsing.provider.0.reportGenericURL", "http://{moz:locale}.phish-generic.mozilla.com/?hl={moz:locale}");
 pref("browser.safebrowsing.provider.0.reportErrorURL", "http://{moz:locale}.phish-error.mozilla.com/?hl={moz:locale}");
 pref("browser.safebrowsing.provider.0.reportPhishURL", "http://{moz:locale}.phish-report.mozilla.com/?hl={moz:locale}");
+pref("browser.safebrowsing.provider.0.reportMalwareURL", "http://{moz:locale}.malware-report.mozilla.com/?hl={moz:locale}");
+pref("browser.safebrowsing.provider.0.reportMalwareErrorURL", "http://{moz:locale}.malware-error.mozilla.com/?hl={moz:locale}");
 
-// FAQ URL
-pref("browser.safebrowsing.warning.infoURL", "http://%LOCALE%.www.mozilla.com/%LOCALE%/firefox/phishing-protection/");
+// FAQ URLs
+pref("browser.safebrowsing.warning.infoURL", "http://www.mozilla.com/%LOCALE%/%APP%/phishing-protection/");
+pref("browser.geolocation.warning.infoURL", "http://www.mozilla.com/%LOCALE%/%APP%/geolocation/");
 
 // Name of the about: page contributed by safebrowsing to handle display of error
 // pages on phishing/malware hits.  (bug 399233)
@@ -565,17 +651,17 @@ pref("urlclassifier.gethashtables", "goog-phish-shavar,goog-malware-shavar");
 // the database.
 pref("urlclassifier.confirm-age", 2700);
 
-//@line 644 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 744 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 
 // Maximum size of the sqlite3 cache during an update, in bytes
-//@line 647 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 747 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("urlclassifier.updatecachemax", 104857600);
-//@line 651 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 751 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 
 // URL for checking the reason for a malware warning.
 pref("browser.safebrowsing.malware.reportURL", "http://safebrowsing.clients.google.com/safebrowsing/diagnostic?client=%NAME%&hl=%LOCALE%&site=");
 
-//@line 656 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/browser/app/profile/firefox.js"
+//@line 756 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 
 pref("browser.EULA.version", 3);
 pref("browser.rights.version", 3);
@@ -584,8 +670,9 @@ pref("browser.rights.3.shown", false);
 // Don't show the about:rights notification
 pref("browser.rights.override", true);
 
-pref("browser.sessionstore.enabled", true);
+//@line 767 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("browser.sessionstore.resume_from_crash", true);
+//@line 769 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
 pref("browser.sessionstore.resume_session_once", false);
 
 // minimal interval between two save operations in milliseconds
@@ -598,35 +685,20 @@ pref("browser.sessionstore.postdata", 0);
 pref("browser.sessionstore.privacy_level", 1);
 // how many tabs can be reopened (per window)
 pref("browser.sessionstore.max_tabs_undo", 10);
+// how many windows can be reopened (per session) - on non-OS X platforms this
+// pref may be ignored when dealing with pop-up windows to ensure proper startup
+pref("browser.sessionstore.max_windows_undo", 3);
+// number of crashes that can occur before the about:sessionrestore page is displayed
+// (this pref has no effect if more than 6 hours have passed since the last crash)
+pref("browser.sessionstore.max_resumed_crashes", 1);
 
 // allow META refresh by default
 pref("accessibility.blockautorefresh", false);
 
-// If true, will migrate uri post-data annotations to
-// bookmark post-data annotations (bug 398914)
-// XXX to be removed after beta 2 (bug 391419)
-pref("browser.places.migratePostDataAnnotations", true);
-
-// If true, will update the Smart Bookmarks uri for
-// recent tags (bug 385245). Useful just for FX3 beta users.
-pref("browser.places.updateRecentTagsUri", true);
-
 // the (maximum) number of the recent visits to sample
 // when calculating frecency
 pref("places.frecency.numVisits", 10);
 
-// Number of records to update frecency for when idle.
-pref("places.frecency.numCalcOnIdle", 50);
-
-// Number of records to update frecency for when migrating from
-// a pre-frecency build.
-pref("places.frecency.numCalcOnMigrate", 50);
-
-// Perform frecency recalculation after this amount of idle, repeating.
-// A value of zero disables updating of frecency on idle.
-// Default is 1 minute (60000ms).
-pref("places.frecency.updateIdleTime", 60000);
-
 // buckets (in days) for frecency calculation
 pref("places.frecency.firstBucketCutoff", 4);
 pref("places.frecency.secondBucketCutoff", 14);
@@ -644,7 +716,7 @@ pref("places.frecency.defaultBucketWeight", 10);
 pref("places.frecency.embedVisitBonus", 0);
 pref("places.frecency.linkVisitBonus", 100);
 pref("places.frecency.typedVisitBonus", 2000);
-pref("places.frecency.bookmarkVisitBonus", 150);
+pref("places.frecency.bookmarkVisitBonus", 75);
 pref("places.frecency.downloadVisitBonus", 0);
 pref("places.frecency.permRedirectVisitBonus", 0);
 pref("places.frecency.tempRedirectVisitBonus", 0);
@@ -658,13 +730,13 @@ pref("places.frecency.unvisitedTypedBonus", 200);
 // 0 - don't pre-populate anything
 // 1 - pre-populate site URL, but don't fetch certificate
 // 2 - pre-populate site URL and pre-fetch certificate
-pref("browser.ssl_override_behavior", 1);
+pref("browser.ssl_override_behavior", 2);
 
 // Controls the display of domain in the identity box for SSL connections.
 // 0 - do not show domain
 // 1 - show effectiveTLD + 1 (e.g. mozilla.org)
 // 2 - show full domain (e.g. bugzilla.mozilla.org)
-pref("browser.identity.ssl_domain_display", 0);
+pref("browser.identity.ssl_domain_display", 1);
 
 // True if the user should be prompted when a web application supports
 // offline apps.
@@ -676,6 +748,9 @@ pref("browser.zoom.full", true);
 // Whether or not to save and restore zoom levels on a per-site basis.
 pref("browser.zoom.siteSpecific", true);
 
+// Whether or not to update background tabs to the current zoom level.
+pref("browser.zoom.updateBackgroundTabs", true);
+
 // replace newlines with spaces when pasting into <input type="text"> fields
 pref("editor.singleLine.pasteNewlines", 2);
 
@@ -684,3 +759,36 @@ pref("breakpad.reportURL", "http://crash-stats.mozilla.com/report/index/");
 
 // base URL for web-based support pages
 pref("app.support.baseURL", "http://support.mozilla.com/1/%APP%/%VERSION%/%OS%/%LOCALE%/");
+
+// Name of alternate about: page for certificate errors (when undefined, defaults to about:neterror)
+pref("security.alternate_certificate_error_page", "certerror");
+
+// Whether to start the private browsing mode at application startup
+pref("browser.privatebrowsing.autostart", false);
+
+// Whether we should skip prompting before starting the private browsing mode
+pref("browser.privatebrowsing.dont_prompt_on_enter", false);
+
+// Don't try to alter this pref, it'll be reset the next time you use the
+// bookmarking dialog
+pref("browser.bookmarks.editDialog.firstEditField", "namePicker");
+
+// base url for the wifi geolocation network provider
+pref("geo.wifi.uri", "https://www.google.com/loc/json");
+
+//@line 902 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
+
+// Whether to use a panel that looks like an OS X sheet for customization
+//@line 907 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
+pref("toolbar.customization.usesheet", false);
+//@line 909 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
+
+// Whitelist the test plugin, Flash, Silverlight, and QuickTime
+ 
+pref("dom.ipc.plugins.enabled.libnptest.so.22.0", true);
+//@line 919 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
+pref("dom.ipc.plugins.enabled.libflashplayer.so", true);
+//@line 921 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/browser/app/profile/firefox.js"
+
+pref("dom.ipc.plugins.enabled", false);
+
