@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/toolkit/components/console/content/console.js"
+//@line 39 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/components/console/content/console.js"
 
 var gConsole, gConsoleBundle, gTextBoxEval, gEvaluator, gCodeToEvaluate;
 
@@ -57,7 +57,10 @@ function updateSortCommand(aOrder)
 
 function updateModeCommand(aMode)
 {
-  var bc = document.getElementById("Console:mode" + aMode);
+  /* aMode can end up invalid if it set by an extension that replaces */
+  /* mode and then it is uninstalled or disabled */
+  var bc = document.getElementById("Console:mode" + aMode) ||
+           document.getElementById("Console:modeAll");
   bc.setAttribute("checked", true);
 }
 
