@@ -1,4 +1,4 @@
-//@line 40 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/toolkit/content/customizeToolbar.js"
+//@line 40 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/content/customizeToolbar.js"
 
 const kRowMax = 4;
 
@@ -7,24 +7,49 @@ var gToolbox = null;
 var gCurrentDragOverItem = null;
 var gToolboxChanged = false;
 var gToolboxIconSize = false;
+var gToolboxSheet = false;
 
 function onLoad()
 {
-  InitWithToolbox(window.arguments[0]);
-  repositionDialog();
+  if ("arguments" in window && window.arguments[0]) {
+    InitWithToolbox(window.arguments[0]);
+    repositionDialog();
+  }
+  else if (window.frameElement &&
+           "toolbox" in window.frameElement) {
+    gToolboxSheet = true;
+    InitWithToolbox(window.frameElement.toolbox);
+  }
 }
 
 function InitWithToolbox(aToolbox)
 {
   gToolbox = aToolbox;
   gToolboxDocument = gToolbox.ownerDocument;
-  
-  gToolbox.addEventListener("draggesture", onToolbarDragGesture, false);
+  gToolbox.customizing = true;
+
+  gToolbox.addEventListener("dragstart", onToolbarDragStart, false);
   gToolbox.addEventListener("dragover", onToolbarDragOver, false);
-  gToolbox.addEventListener("dragexit", onToolbarDragExit, false);
-  gToolbox.addEventListener("dragdrop", onToolbarDragDrop, false);
+  gToolbox.addEventListener("dragleave", onToolbarDragLeave, false);
+  gToolbox.addEventListener("drop", onToolbarDrop, false);
 
   initDialog();
+
+  notifyParentInitialized();
+}
+
+function onClose()
+{
+  if (!gToolboxSheet)
+    window.close();
+  else
+    finishToolbarCustomization();
+}
+
+function onUnload()
+{
+  if (!gToolboxSheet)
+    finishToolbarCustomization();
 }
 
 function finishToolbarCustomization()
@@ -32,7 +57,8 @@ function finishToolbarCustomization()
   removeToolboxListeners();
   unwrapToolbarItems();
   persistCurrentSets();
-  
+  gToolbox.customizing = false;
+
   notifyParentComplete();
 }
 
@@ -55,14 +81,14 @@ function initDialog()
 
 function repositionDialog()
 {
-  // Position the dialog touching the bottom of the toolbox and centered with 
+  // Position the dialog touching the bottom of the toolbox and centered with
   // it.
   var width;
   if (document.documentElement.hasAttribute("width"))
     width = document.documentElement.getAttribute("width");
   else
     width = parseInt(document.documentElement.style.width);
-  var screenX = gToolbox.boxObject.screenX 
+  var screenX = gToolbox.boxObject.screenX
                 + ((gToolbox.boxObject.width - width) / 2);
   var screenY = gToolbox.boxObject.screenY + gToolbox.boxObject.height;
 
@@ -71,10 +97,10 @@ function repositionDialog()
 
 function removeToolboxListeners()
 {
-  gToolbox.removeEventListener("draggesture", onToolbarDragGesture, false);
+  gToolbox.removeEventListener("dragstart", onToolbarDragStart, false);
   gToolbox.removeEventListener("dragover", onToolbarDragOver, false);
-  gToolbox.removeEventListener("dragexit", onToolbarDragExit, false);
-  gToolbox.removeEventListener("dragdrop", onToolbarDragDrop, false);
+  gToolbox.removeEventListener("dragleave", onToolbarDragLeave, false);
+  gToolbox.removeEventListener("drop", onToolbarDrop, false);
 }
 
 /**
@@ -87,11 +113,21 @@ function notifyParentComplete()
     gToolbox.customizeDone(gToolboxChanged);
 }
 
-function toolboxChanged()
+/**
+ * Invoke a callback on the toolbox to notify it that the dialog is fully
+ * initialized.
+ */
+function notifyParentInitialized()
+{
+  if ("customizeInitialized" in gToolbox)
+    gToolbox.customizeInitialized();
+}
+
+function toolboxChanged(aEvent)
 {
   gToolboxChanged = true;
   if ("customizeChange" in gToolbox)
-    gToolbox.customizeChange();
+    gToolbox.customizeChange(aEvent);
 }
 
 function getToolbarAt(i)
@@ -116,7 +152,7 @@ function persistCurrentSets()
       // Calculate currentset and store it in the attribute.
       var currentSet = toolbar.currentSet;
       toolbar.setAttribute("currentset", currentSet);
-      
+
       var customIndex = toolbar.hasAttribute("customindex");
       if (customIndex) {
         if (!toolbar.firstChild) {
@@ -137,7 +173,7 @@ function persistCurrentSets()
       }
     }
   }
-  
+
   // Remove toolbarX attributes for removed toolbars.
   while (gToolbox.toolbarset.hasAttribute("toolbar"+(++customCount))) {
     gToolbox.toolbarset.removeAttribute("toolbar"+customCount);
@@ -156,18 +192,10 @@ function wrapToolbarItems()
       for (var k = 0; k < toolbar.childNodes.length; ++k) {
         var item = toolbar.childNodes[k];
 
-//@line 201 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/toolkit/content/customizeToolbar.js"
+//@line 237 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/content/customizeToolbar.js"
 
         if (isToolbarItem(item)) {
-          var nextSibling = item.nextSibling;
-          
           var wrapper = wrapToolbarItem(item);
-          
-          if (nextSibling)
-            toolbar.insertBefore(wrapper, nextSibling);
-          else
-            toolbar.appendChild(wrapper);
-
           cleanupItemForToolbar(item, wrapper);
         }
       }
@@ -188,8 +216,13 @@ function unwrapToolbarItems()
     if (paletteItem.hasAttribute("itemdisabled"))
       toolbarItem.disabled = true;
 
-    if (paletteItem.hasAttribute("itemcommand"))
-      toolbarItem.setAttribute("command", paletteItem.getAttribute("itemcommand"));
+    if (paletteItem.hasAttribute("itemcommand")) {
+      let commandID = paletteItem.getAttribute("itemcommand");
+      toolbarItem.setAttribute("command", commandID);
+
+      //XXX Bug 309953 - toolbarbuttons aren't in sync with their commands after customizing
+      toolbarItem.disabled = gToolboxDocument.getElementById(commandID).disabled;
+    }
 
     paletteItem.parentNode.replaceChild(toolbarItem, paletteItem);
   }
@@ -199,12 +232,12 @@ function unwrapToolbarItems()
  * Creates a wrapper that can be used to contain a toolbaritem and prevent
  * it from receiving UI events.
  */
-function createWrapper(aId)
+function createWrapper(aId, aDocument)
 {
-  var wrapper = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul",
+  var wrapper = aDocument.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul",
                                          "toolbarpaletteitem");
 
-  wrapper.id = "wrapper-"+aId;  
+  wrapper.id = "wrapper-"+aId;
   return wrapper;
 }
 
@@ -214,7 +247,7 @@ function createWrapper(aId)
  */
 function wrapPaletteItem(aPaletteItem, aCurrentRow, aSpacer)
 {
-  var wrapper = createWrapper(aPaletteItem.id);
+  var wrapper = createWrapper(aPaletteItem.id, document);
 
   wrapper.setAttribute("flex", 1);
   wrapper.setAttribute("align", "center");
@@ -222,11 +255,10 @@ function wrapPaletteItem(aPaletteItem, aCurrentRow, aSpacer)
   wrapper.setAttribute("minheight", "0");
   wrapper.setAttribute("minwidth", "0");
 
-  document.adoptNode(aPaletteItem);
   wrapper.appendChild(aPaletteItem);
-  
+
   // XXX We need to call this AFTER the palette item has been appended
-  // to the wrapper or else we crash dropping certain buttons on the 
+  // to the wrapper or else we crash dropping certain buttons on the
   // palette due to removal of the command and disabled attributes - JRH
   cleanUpItemForPalette(aPaletteItem, wrapper);
 
@@ -244,16 +276,14 @@ function wrapPaletteItem(aPaletteItem, aCurrentRow, aSpacer)
  */
 function wrapToolbarItem(aToolbarItem)
 {
-  var wrapper = createWrapper(aToolbarItem.id);
-  gToolboxDocument.adoptNode(wrapper);
+  var wrapper = createWrapper(aToolbarItem.id, gToolboxDocument);
 
   wrapper.flex = aToolbarItem.flex;
 
-  if (aToolbarItem.parentNode)
-    aToolbarItem.parentNode.removeChild(aToolbarItem);
-  
+  aToolbarItem.parentNode.replaceChild(wrapper, aToolbarItem);
+
   wrapper.appendChild(aToolbarItem);
-  
+
   return wrapper;
 }
 
@@ -318,7 +348,7 @@ function buildPalette()
   while (templateNode) {
     // Check if the item is already in a toolbar before adding it to the palette.
     if (!(templateNode.id in currentItems)) {
-      var paletteItem = templateNode.cloneNode(true);
+      var paletteItem = document.importNode(templateNode, true);
 
       if (rowSlot == kRowMax) {
         // Append the old row.
@@ -334,11 +364,11 @@ function buildPalette()
       ++rowSlot;
       wrapPaletteItem(paletteItem, currentRow, null);
     }
-    
+
     templateNode = templateNode.nextSibling;
   }
 
-  if (currentRow) { 
+  if (currentRow) {
     fillRowWithFlex(currentRow);
     paletteBox.appendChild(currentRow);
   }
@@ -353,14 +383,14 @@ function appendPaletteItem(aItem)
   var paletteBox = document.getElementById("palette-box");
   var lastRow = paletteBox.lastChild;
   var lastSpacer = lastRow.lastChild;
-   
+
   if (lastSpacer.localName != "spacer") {
     // The current row is full, so we have to create a new row.
     lastRow = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul",
                                         "hbox");
     lastRow.setAttribute("class", "paletteRow");
     paletteBox.appendChild(lastRow);
-    
+
     wrapPaletteItem(aItem, lastRow, null);
 
     fillRowWithFlex(lastRow);
@@ -391,7 +421,7 @@ function fillRowWithFlex(aRow)
 
 /**
  * Makes sure that an item that has been cloned from a template
- * is stripped of all properties that may adversely affect it's
+ * is stripped of any attributes that may adversely affect its
  * appearance in the palette.
  */
 function cleanUpItemForPalette(aItem, aWrapper)
@@ -403,19 +433,22 @@ function cleanUpItemForPalette(aItem, aWrapper)
     aWrapper.setAttribute("title", aItem.getAttribute("title"));
   else if (isSpecialItem(aItem)) {
     var stringBundle = document.getElementById("stringBundle");
-    var title = stringBundle.getString(aItem.id + "Title");
+    // Remove the common "toolbar" prefix to generate the string name.
+    var title = stringBundle.getString(aItem.localName.slice(7) + "Title");
     aWrapper.setAttribute("title", title);
   }
-  
+
   // Remove attributes that screw up our appearance.
   aItem.removeAttribute("command");
   aItem.removeAttribute("observes");
-  aItem.removeAttribute("disabled");
   aItem.removeAttribute("type");
-  
-  if (aItem.localName == "toolbaritem" && aItem.firstChild) {
-    aItem.firstChild.removeAttribute("observes");
+  aItem.removeAttribute("width");
 
+  Array.forEach(aWrapper.querySelectorAll("[disabled]"), function(aNode) {
+    aNode.removeAttribute("disabled");
+  });
+
+  if (aItem.localName == "toolbaritem" && aItem.firstChild) {
     // So the throbber doesn't throb in the dialog,
     // cute as that may be...
     aItem.firstChild.removeAttribute("busy");
@@ -424,8 +457,8 @@ function cleanUpItemForPalette(aItem, aWrapper)
 
 /**
  * Makes sure that an item that has been cloned from a template
- * is stripped of all properties that may adversely affect it's
- * appearance in the toolbar.  Store critical properties on the 
+ * is stripped of all properties that may adversely affect its
+ * appearance in the toolbar.  Store critical properties on the
  * wrapper so they can be put back on the item when we're done.
  */
 function cleanupItemForToolbar(aItem, aWrapper)
@@ -466,10 +499,10 @@ function setDragActive(aItem, aValue)
     node = aItem.lastChild;
     value = direction == "ltr"? "right" : "left";
   }
-  
+
   if (!node)
     return;
-  
+
   if (aValue) {
     if (!node.hasAttribute("dragover"))
       node.setAttribute("dragover", value);
@@ -501,7 +534,7 @@ function addNewToolbar()
       doneButton.disabled = false;
       return;
     }
-    
+
     if (!name.value) {
       message = stringBundle.getFormattedString("enterToolbarBlank", [name.value]);
       continue;
@@ -527,9 +560,9 @@ function addNewToolbar()
 
     message = stringBundle.getFormattedString("enterToolbarDup", [name.value]);
   }
-    
+
   gToolbox.appendCustomToolbar(name.value, "");
-  
+
   toolboxChanged();
 
   doneButton.disabled = false;
@@ -541,9 +574,8 @@ function addNewToolbar()
  */
 function restoreDefaultSet()
 {
-  // Save disabled/command states, because we're
-  // going to recreate the wrappers and lose this
-  var savedAttributes = saveItemAttributes(["itemdisabled", "itemcommand"]);
+  // Unwrap the items on the toolbar.
+  unwrapToolbarItems();
 
   // Remove all of the customized toolbars.
   var child = gToolbox.lastChild;
@@ -551,6 +583,7 @@ function restoreDefaultSet()
     if (child.hasAttribute("customindex")) {
       var thisChild = child;
       child = child.previousSibling;
+      thisChild.currentSet = "__empty";
       gToolbox.removeChild(thisChild);
     } else {
       child = child.previousSibling;
@@ -583,56 +616,16 @@ function restoreDefaultSet()
   // Now re-wrap the items on the toolbar.
   wrapToolbarItems();
 
-  // Restore the disabled and command states
-  restoreItemAttributes(["itemdisabled", "itemcommand"], savedAttributes);
-
-  toolboxChanged();
-}
-
-function saveItemAttributes(aAttributeList)
-{
-  var items = [];
-  var paletteItems = gToolbox.getElementsByTagName("toolbarpaletteitem");
-  for (var i = 0; i < paletteItems.length; i++) {
-    var paletteItem = paletteItems.item(i);
-    for (var j = 0; j < aAttributeList.length; j++) {
-      var attr = aAttributeList[j];
-      if (paletteItem.hasAttribute(attr)) {
-        items.push([paletteItem.id, attr, paletteItem.getAttribute(attr)]);
-      }
-    }
-  }
-  return items;
-}
-
-function restoreItemAttributes(aAttributeList, aSavedAttrList)
-{
-  var paletteItems = gToolbox.getElementsByTagName("toolbarpaletteitem");
-
-  for (var i = 0; i < paletteItems.length; i++) {
-    var paletteItem = paletteItems.item(i);
-
-    // if the item is supposed to have this, it'll get
-    // restored from the saved list
-    for (var j = 0; j < aAttributeList.length; j++)
-      paletteItem.removeAttribute(aAttributeList[j]);
-
-    for (var j = 0; j < aSavedAttrList.length; j++) {
-      var savedAttr = aSavedAttrList[j];
-      if (paletteItem.id == savedAttr[0]) {
-        paletteItem.setAttribute(savedAttr[1], savedAttr[2]);
-      }
-    }
-  }
+  toolboxChanged("reset");
 }
 
 function updateIconSize(aUseSmallIcons, localDefault)
 {
   gToolboxIconSize = aUseSmallIcons ? "small" : "large";
-  
+
   setAttribute(gToolbox, "iconsize", gToolboxIconSize);
   gToolboxDocument.persist(gToolbox.id, "iconsize");
-  
+
   for (var i = 0; i < gToolbox.childNodes.length; ++i) {
     var toolbar = getToolbarAt(i);
     if (isCustomizableToolbar(toolbar)) {
@@ -699,273 +692,219 @@ function isToolbarItem(aElt)
 ///////////////////////////////////////////////////////////////////////////
 //// Drag and Drop observers
 
-function onToolbarDragGesture(aEvent)
-{
-  nsDragAndDrop.startDrag(aEvent, dragStartObserver);
-}
-
-function onToolbarDragOver(aEvent)
-{
-  nsDragAndDrop.dragOver(aEvent, toolbarDNDObserver);
-}
-
-function onToolbarDragDrop(aEvent)
-{
-  nsDragAndDrop.drop(aEvent, toolbarDNDObserver);
-}
-
-function onToolbarDragExit(aEvent)
+function onToolbarDragLeave(aEvent)
 {
   if (gCurrentDragOverItem)
     setDragActive(gCurrentDragOverItem, false);
 }
 
-var dragStartObserver =
+function onToolbarDragStart(aEvent)
 {
-  onDragStart: function (aEvent, aXferData, aDragAction) {
-    var documentId = gToolboxDocument.documentElement.id;
-    
-    var item = aEvent.target;
-    while (item && item.localName != "toolbarpaletteitem")
-      item = item.parentNode;
-    
-    item.setAttribute("dragactive", "true");
-    
-    aXferData.data = new TransferDataSet();
-    var data = new TransferData();
-    data.addDataForFlavour("text/toolbarwrapper-id/"+documentId, item.firstChild.id);
-    aXferData.data.push(data);
-    aDragAction.action = Components.interfaces.nsIDragService.DRAGDROP_ACTION_MOVE;
-  }
+  var documentId = gToolboxDocument.documentElement.id;
+
+  var item = aEvent.target;
+  while (item && item.localName != "toolbarpaletteitem")
+    item = item.parentNode;
+
+  item.setAttribute("dragactive", "true");
+
+  var dt = aEvent.dataTransfer;
+  dt.setData("text/toolbarwrapper-id/" + documentId, item.firstChild.id);
+  dt.effectAllowed = "move";
 }
 
-var toolbarDNDObserver =
+function onToolbarDragOver(aEvent)
 {
-  onDragOver: function (aEvent, aFlavour, aDragSession)
-  {
-    var toolbar = aEvent.target;
-    var dropTarget = aEvent.target;
-    while (toolbar && toolbar.localName != "toolbar") {
-      dropTarget = toolbar;
-      toolbar = toolbar.parentNode;
-    }
-    
-    var previousDragItem = gCurrentDragOverItem;
+  var documentId = gToolboxDocument.documentElement.id;
+  if (!aEvent.dataTransfer.types.contains("text/toolbarwrapper-id/" + documentId))
+    return;
 
-    // Make sure we are dragging over a customizable toolbar.
-    if (!isCustomizableToolbar(toolbar)) {
-      gCurrentDragOverItem = null;
-      return;
-    }
-    
-    if (dropTarget.localName == "toolbar") {
-      gCurrentDragOverItem = dropTarget;
-    } else {
-      gCurrentDragOverItem = null;
+  var toolbar = aEvent.target;
+  var dropTarget = aEvent.target;
+  while (toolbar && toolbar.localName != "toolbar") {
+    dropTarget = toolbar;
+    toolbar = toolbar.parentNode;
+  }
 
-      var direction = window.getComputedStyle(dropTarget.parentNode, null).direction;
-      var dropTargetCenter = dropTarget.boxObject.x + (dropTarget.boxObject.width / 2);
-      if (direction == "ltr")
-        dragAfter = aEvent.clientX > dropTargetCenter;
-      else
-        dragAfter = aEvent.clientX < dropTargetCenter;
-        
-      if (dragAfter) {
-        gCurrentDragOverItem = dropTarget.nextSibling;
-        if (!gCurrentDragOverItem)
-          gCurrentDragOverItem = toolbar;
-      } else
-        gCurrentDragOverItem = dropTarget;
-    }    
+  var previousDragItem = gCurrentDragOverItem;
 
-    if (previousDragItem && gCurrentDragOverItem != previousDragItem) {
-      setDragActive(previousDragItem, false);
-    }
-    
-    setDragActive(gCurrentDragOverItem, true);
-    
-    aDragSession.canDrop = true;
-  },
-  
-  onDrop: function (aEvent, aXferData, aDragSession)
-  {
-    if (!gCurrentDragOverItem)
-      return;
-    
-    setDragActive(gCurrentDragOverItem, false);
+  // Make sure we are dragging over a customizable toolbar.
+  if (!isCustomizableToolbar(toolbar)) {
+    gCurrentDragOverItem = null;
+    return;
+  }
 
-    var draggedItemId = aXferData.data;
-    if (gCurrentDragOverItem.id == draggedItemId)
-      return;
-
-    var toolbar = aEvent.target;
-    while (toolbar.localName != "toolbar")
-      toolbar = toolbar.parentNode;
-
-    var draggedPaletteWrapper = document.getElementById("wrapper-"+draggedItemId);       
-    if (!draggedPaletteWrapper) {
-      // The wrapper has been dragged from the toolbar.
-      
-      // Get the wrapper from the toolbar document and make sure that
-      // it isn't being dropped on itself.
-      var wrapper = gToolboxDocument.getElementById("wrapper-"+draggedItemId);
-      if (wrapper == gCurrentDragOverItem)
-        return;
-
-      // Don't allow static kids (e.g., the menubar) to move.
-      if (wrapper.parentNode.firstPermanentChild && wrapper.parentNode.firstPermanentChild.id == wrapper.firstChild.id)
-        return;
-      if (wrapper.parentNode.lastPermanentChild && wrapper.parentNode.lastPermanentChild.id == wrapper.firstChild.id)
-        return;
-
-      // Remove the item from it's place in the toolbar.
-      wrapper.parentNode.removeChild(wrapper);
-
-      // Determine which toolbar we are dropping on.
-      var dropToolbar = null;
-      if (gCurrentDragOverItem.localName == "toolbar")
-        dropToolbar = gCurrentDragOverItem;
-      else
-        dropToolbar = gCurrentDragOverItem.parentNode;
-      
-      // Insert the item into the toolbar.
-      if (gCurrentDragOverItem != dropToolbar)
-        dropToolbar.insertBefore(wrapper, gCurrentDragOverItem);
-      else
-        dropToolbar.appendChild(wrapper);
-    } else {
-      // The item has been dragged from the palette
-      
-      // Create a new wrapper for the item. We don't know the id yet.
-      var wrapper = createWrapper("");
-      gToolboxDocument.adoptNode(wrapper);
-
-      // Ask the toolbar to clone the item's template, place it inside the wrapper, and insert it in the toolbar.
-      var newItem = toolbar.insertItem(draggedItemId, gCurrentDragOverItem == toolbar ? null : gCurrentDragOverItem, wrapper);
-      
-      // Prepare the item and wrapper to look good on the toolbar.
-      cleanupItemForToolbar(newItem, wrapper);
-      wrapper.id = "wrapper-"+newItem.id;
-      wrapper.flex = newItem.flex;
-
-      // Remove the wrapper from the palette.
-      var currentRow = draggedPaletteWrapper.parentNode;
-      if (draggedItemId != "separator" &&
-          draggedItemId != "spring" &&
-          draggedItemId != "spacer")
-      {
-        currentRow.removeChild(draggedPaletteWrapper);
-
-        while (currentRow) {
-          // Pull the first child of the next row up
-          // into this row.
-          var nextRow = currentRow.nextSibling;
-          
-          if (!nextRow) {
-            var last = currentRow.lastChild;
-            var first = currentRow.firstChild;
-            if (first == last) {
-              // Kill the row.
-              currentRow.parentNode.removeChild(currentRow);
-              break;
-            }
-
-            if (last.localName == "spacer") {
-              var flex = last.getAttribute("flex");
-              last.setAttribute("flex", ++flex);
-              // Reflow doesn't happen for some reason.  Trigger it with a hide/show. ICK! -dwh
-              last.hidden = true;
-              last.hidden = false;
-              break;
-            } else {
-              // Make a spacer and give it a flex of 1.
-              var spacer = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul",
-                                                    "spacer");
-              spacer.setAttribute("flex", "1");
-              currentRow.appendChild(spacer);
-            }
-            break;
-          }
-          
-          currentRow.appendChild(nextRow.firstChild);
-          currentRow = currentRow.nextSibling;
-        }
-      }
-    }
-    
+  if (dropTarget.localName == "toolbar") {
+    gCurrentDragOverItem = dropTarget;
+  } else {
     gCurrentDragOverItem = null;
 
-    toolboxChanged();
-  },
-  
-  _flavourSet: null,
-  
-  getSupportedFlavours: function ()
-  {
-    if (!this._flavourSet) {
-      this._flavourSet = new FlavourSet();
-      var documentId = gToolboxDocument.documentElement.id;
-      this._flavourSet.appendFlavour("text/toolbarwrapper-id/"+documentId);
-    }
-    return this._flavourSet;
+    var direction = window.getComputedStyle(dropTarget.parentNode, null).direction;
+    var dropTargetCenter = dropTarget.boxObject.x + (dropTarget.boxObject.width / 2);
+    var dragAfter;
+    if (direction == "ltr")
+      dragAfter = aEvent.clientX > dropTargetCenter;
+    else
+      dragAfter = aEvent.clientX < dropTargetCenter;
+
+    if (dragAfter) {
+      gCurrentDragOverItem = dropTarget.nextSibling;
+      if (!gCurrentDragOverItem)
+        gCurrentDragOverItem = toolbar;
+    } else
+      gCurrentDragOverItem = dropTarget;
   }
+
+  if (previousDragItem && gCurrentDragOverItem != previousDragItem) {
+    setDragActive(previousDragItem, false);
+  }
+
+  setDragActive(gCurrentDragOverItem, true);
+
+  aEvent.preventDefault();
 }
 
-var paletteDNDObserver =
+function onToolbarDrop(aEvent)
 {
-  onDragOver: function (aEvent, aFlavour, aDragSession)
-  {
-    aDragSession.canDrop = true;
-  },
-  
-  onDrop: function(aEvent, aXferData, aDragSession)
-  {
-    var itemId = aXferData.data;
-    
-    var wrapper = gToolboxDocument.getElementById("wrapper-"+itemId);
-    if (wrapper) {
-      // Don't allow static kids (e.g., the menubar) to move.
-      if (wrapper.parentNode.firstPermanentChild && wrapper.parentNode.firstPermanentChild.id == wrapper.firstChild.id)
-        return;
-      if (wrapper.parentNode.lastPermanentChild && wrapper.parentNode.lastPermanentChild.id == wrapper.firstChild.id)
-        return;
+  if (!gCurrentDragOverItem)
+    return;
 
-      // The item was dragged out of the toolbar.
-      wrapper.parentNode.removeChild(wrapper);
-      
-      var wrapperType = wrapper.getAttribute("type");
-      if (wrapperType != "separator" &&
-          wrapperType != "spacer" &&
-          wrapperType != "spring") {
-        // Find the template node in the toolbox palette
-        var templateNode = gToolbox.palette.firstChild;
-        while (templateNode) {
-          if (templateNode.id == itemId)
+  setDragActive(gCurrentDragOverItem, false);
+
+  var documentId = gToolboxDocument.documentElement.id;
+  var draggedItemId = aEvent.dataTransfer.getData("text/toolbarwrapper-id/" + documentId);
+  if (gCurrentDragOverItem.id == draggedItemId)
+    return;
+
+  var toolbar = aEvent.target;
+  while (toolbar.localName != "toolbar")
+    toolbar = toolbar.parentNode;
+
+  var draggedPaletteWrapper = document.getElementById("wrapper-"+draggedItemId);
+  if (!draggedPaletteWrapper) {
+    // The wrapper has been dragged from the toolbar.
+    // Get the wrapper from the toolbar document and make sure that
+    // it isn't being dropped on itself.
+    var wrapper = gToolboxDocument.getElementById("wrapper-"+draggedItemId);
+    if (wrapper == gCurrentDragOverItem)
+       return;
+
+    // Don't allow static kids (e.g., the menubar) to move.
+    if (wrapper.parentNode.firstPermanentChild && wrapper.parentNode.firstPermanentChild.id == wrapper.firstChild.id)
+      return;
+    if (wrapper.parentNode.lastPermanentChild && wrapper.parentNode.lastPermanentChild.id == wrapper.firstChild.id)
+      return;
+
+    // Remove the item from its place in the toolbar.
+    wrapper.parentNode.removeChild(wrapper);
+
+    // Determine which toolbar we are dropping on.
+    var dropToolbar = null;
+    if (gCurrentDragOverItem.localName == "toolbar")
+      dropToolbar = gCurrentDragOverItem;
+    else
+      dropToolbar = gCurrentDragOverItem.parentNode;
+
+    // Insert the item into the toolbar.
+    if (gCurrentDragOverItem != dropToolbar)
+      dropToolbar.insertBefore(wrapper, gCurrentDragOverItem);
+    else
+      dropToolbar.appendChild(wrapper);
+  } else {
+    // The item has been dragged from the palette
+
+    // Create a new wrapper for the item. We don't know the id yet.
+    var wrapper = createWrapper("", gToolboxDocument);
+
+    // Ask the toolbar to clone the item's template, place it inside the wrapper, and insert it in the toolbar.
+    var newItem = toolbar.insertItem(draggedItemId, gCurrentDragOverItem == toolbar ? null : gCurrentDragOverItem, wrapper);
+
+    // Prepare the item and wrapper to look good on the toolbar.
+    cleanupItemForToolbar(newItem, wrapper);
+    wrapper.id = "wrapper-"+newItem.id;
+    wrapper.flex = newItem.flex;
+
+    // Remove the wrapper from the palette.
+    var currentRow = draggedPaletteWrapper.parentNode;
+    if (draggedItemId != "separator" &&
+        draggedItemId != "spring" &&
+        draggedItemId != "spacer")
+    {
+      currentRow.removeChild(draggedPaletteWrapper);
+
+      while (currentRow) {
+        // Pull the first child of the next row up
+        // into this row.
+        var nextRow = currentRow.nextSibling;
+
+        if (!nextRow) {
+          var last = currentRow.lastChild;
+          var first = currentRow.firstChild;
+          if (first == last) {
+            // Kill the row.
+            currentRow.parentNode.removeChild(currentRow);
+             break;
+           }
+
+          if (last.localName == "spacer") {
+            var flex = last.getAttribute("flex");
+            last.setAttribute("flex", ++flex);
+            // Reflow doesn't happen for some reason.  Trigger it with a hide/show. ICK! -dwh
+            last.hidden = true;
+            last.hidden = false;
             break;
-          templateNode = templateNode.nextSibling;
+          } else {
+            // Make a spacer and give it a flex of 1.
+            var spacer = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul",
+                                                  "spacer");
+            spacer.setAttribute("flex", "1");
+            currentRow.appendChild(spacer);
+          }
+          break;
         }
-        if (!templateNode)
-          return;
-        
-        // Clone the template and add it to our palette.
-        var paletteItem = templateNode.cloneNode(true);
-        appendPaletteItem(paletteItem);
+
+        currentRow.appendChild(nextRow.firstChild);
+        currentRow = currentRow.nextSibling;
       }
     }
-    
-    toolboxChanged();
-  },
-  
-  _flavourSet: null,
-  
-  getSupportedFlavours: function ()
-  {
-    if (!this._flavourSet) {
-      this._flavourSet = new FlavourSet();
-      var documentId = gToolboxDocument.documentElement.id;
-      this._flavourSet.appendFlavour("text/toolbarwrapper-id/"+documentId);
-    }
-    return this._flavourSet;
   }
+
+  gCurrentDragOverItem = null;
+
+  toolboxChanged();
+};
+
+function onPaletteDragOver(aEvent)
+{
+  var documentId = gToolboxDocument.documentElement.id;
+  if (aEvent.dataTransfer.types.contains("text/toolbarwrapper-id/" + documentId))
+    aEvent.preventDefault();
 }
 
+function onPaletteDrop(aEvent)
+ {
+  var documentId = gToolboxDocument.documentElement.id;
+  var itemId = aEvent.dataTransfer.getData("text/toolbarwrapper-id/" + documentId);
+
+  var wrapper = gToolboxDocument.getElementById("wrapper-"+itemId);
+  if (wrapper) {
+    // Don't allow static kids (e.g., the menubar) to move.
+    if (wrapper.parentNode.firstPermanentChild && wrapper.parentNode.firstPermanentChild.id == wrapper.firstChild.id)
+      return;
+    if (wrapper.parentNode.lastPermanentChild && wrapper.parentNode.lastPermanentChild.id == wrapper.firstChild.id)
+      return;
+
+    var wrapperType = wrapper.getAttribute("type");
+    if (wrapperType != "separator" &&
+        wrapperType != "spacer" &&
+        wrapperType != "spring") {
+      appendPaletteItem(document.importNode(wrapper.firstChild, true));
+      gToolbox.palette.appendChild(wrapper.firstChild);
+    }
+
+    // The item was dragged out of the toolbar.
+    wrapper.parentNode.removeChild(wrapper);
+  }
+
+  toolboxChanged();
+}
