@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/toolkit/content/inlineSpellCheckUI.js"
+//@line 38 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/content/inlineSpellCheckUI.js"
 
 var InlineSpellCheckerUI = {
   mOverMisspelling: false,
@@ -53,7 +53,7 @@ var InlineSpellCheckerUI = {
     if (spellsel.rangeCount == 0)
       return; // easy case - no misspellings
 
-    var range = this.mInlineSpellChecker.getMispelledWord(rangeParent,
+    var range = this.mInlineSpellChecker.getMisspelledWord(rangeParent,
                                                           rangeOffset);
     if (! range)
       return; // not over a misspelled word
@@ -165,7 +165,7 @@ var InlineSpellCheckerUI = {
 
     for (var i = 0; i < list.length; i ++) {
       // get the display name for this dictionary
-      isoStrArray = list[i].split("-");
+      isoStrArray = list[i].split(/[-_]/);
       var displayName = "";
       if (this.mLanguageBundle && isoStrArray[0]) {
         try {
@@ -186,6 +186,7 @@ var InlineSpellCheckerUI = {
 
       this.mDictionaryNames.push(list[i]);
       var item = document.createElement("menuitem");
+      item.setAttribute("id", "spell-check-dictionary-" + list[i]);
       item.setAttribute("label", displayName);
       item.setAttribute("type", "checkbox");
       this.mDictionaryItems.push(item);
