@@ -1,4 +1,4 @@
-//@line 42 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/toolkit/components/printing/content/printdialog.js"
+//@line 42 "/usr/obj/ports/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/components/printing/content/printdialog.js"
 
 var dialog;
 var printService       = null;
@@ -109,9 +109,10 @@ listElement.prototype =
         { 
           if ((null == aDataObject) || !aDataObject.hasMore()) {
             // disable dialog
-            var stringBundle = srGetStrBundle("chrome://global/locale/printing.properties");
             this.listElement.setAttribute("value", "");
-            this.listElement.setAttribute("label", stringBundle.GetStringFromName("noprinter"));
+            this.listElement.setAttribute("label",
+              document.getElementById("printingBundle")
+                      .getString("noprinter"));
 
             this.listElement.setAttribute("disabled", "true");
             dialog.printerLabel.setAttribute("disabled","true");
