@@ -1,10 +1,11 @@
-//@line 44 "/usr/obj/ports/mozilla-firefox-3.0.18/mozilla/toolkit/mozapps/downloads/content/downloads.js"
+//@line 45 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/mozapps/downloads/content/downloads.js"
 
 ////////////////////////////////////////////////////////////////////////////////
 //// Globals
 
 const PREF_BDM_CLOSEWHENDONE = "browser.download.manager.closeWhenDone";
 const PREF_BDM_ALERTONEXEOPEN = "browser.download.manager.alertOnEXEOpen";
+const PREF_BDM_SCANWHENDONE = "browser.download.manager.scanWhenDone";
 
 const nsLocalFile = Components.Constructor("@mozilla.org/file/local;1",
                                            "nsILocalFile", "initWithPath");
@@ -73,19 +74,7 @@ let gStr = {
 };
 
 // The statement to query for downloads that are active or match the search
-let gStmt = gDownloadManager.DBConnection.createStatement(
-  "SELECT id, target, name, source, state, startTime, endTime, referrer, " +
-         "currBytes, maxBytes, state IN (?1, ?2, ?3, ?4, ?5) isActive " +
-  "FROM moz_downloads " +
-  "ORDER BY isActive DESC, endTime DESC, startTime DESC");
-
-////////////////////////////////////////////////////////////////////////////////
-//// Utility Functions
-
-function getDownload(aID)
-{
-  return document.getElementById("dl" + aID);
-}
+let gStmt = null;
 
 ////////////////////////////////////////////////////////////////////////////////
 //// Start/Stop Observers
@@ -114,10 +103,8 @@ function downloadCompleted(aDownload)
       while (next && next.inProgress)
         next = next.nextSibling;
 
-      // Move the item and color everything after where it moved from
-      let fixup = dl.nextSibling;
+      // Move the item
       gDownloadsView.insertBefore(dl, next);
-      stripeifyList(fixup);
     } else {
       removeFromView(dl);
     }
@@ -244,7 +231,7 @@ function showDownload(aDownload)
 function onDownloadDblClick(aEvent)
 {
   // Only do the default action for double primary clicks
-  if (aEvent.button == 0)
+  if (aEvent.button == 0 && aEvent.target.selected)
     doDefaultForSelected();
 }
 
@@ -259,6 +246,8 @@ function openDownload(aDownload)
       dontAsk = !pref.getBoolPref(PREF_BDM_ALERTONEXEOPEN);
     } catch (e) { }
 
+//@line 306 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/mozapps/downloads/content/downloads.js"
+
     if (!dontAsk) {
       var strings = document.getElementById("downloadStrings");
       var name = aDownload.getAttribute("target");
@@ -399,6 +388,7 @@ function Startup()
       gStr[name] = typeof value == "string" ? getStr(value) : value.map(getStr);
   }
 
+  initStatement();
   buildDownloadList(true);
 
   // The DownloadProgressListener (DownloadProgressListener.js) handles progress
@@ -419,19 +409,17 @@ function Startup()
   let obs = Cc["@mozilla.org/observer-service;1"].
             getService(Ci.nsIObserverService);
   obs.addObserver(gDownloadObserver, "download-manager-remove-download", false);
+  obs.addObserver(gDownloadObserver, "private-browsing", false);
+  obs.addObserver(gDownloadObserver, "browser-lastwindow-close-granted", false);
 
   // Clear the search box and move focus to the list on escape from the box
   gSearchBox.addEventListener("keypress", function(e) {
     if (e.keyCode == e.DOM_VK_ESCAPE) {
-      // Clear the input as if the user did it
-      gSearchBox.value = "";
-      gSearchBox.doCommand();
-
       // Move focus to the list instead of closing the window
       gDownloadsView.focus();
       e.preventDefault();
     }
-  }, true);
+  }, false);
 }
 
 function Shutdown()
@@ -440,7 +428,9 @@ function Shutdown()
 
   let obs = Cc["@mozilla.org/observer-service;1"].
             getService(Ci.nsIObserverService);
+  obs.removeObserver(gDownloadObserver, "private-browsing");
   obs.removeObserver(gDownloadObserver, "download-manager-remove-download");
+  obs.removeObserver(gDownloadObserver, "browser-lastwindow-close-granted");
 
   clearTimeout(gBuilder);
   gStmt.reset();
@@ -451,7 +441,7 @@ let gDownloadObserver = {
   observe: function gdo_observe(aSubject, aTopic, aData) {
     switch (aTopic) {
       case "download-manager-remove-download":
-        // A null subject here indicates "remove all"
+        // A null subject here indicates "remove multiple", so we just rebuild.
         if (!aSubject) {
           // Rebuild the default view
           buildDownloadList(true);
@@ -463,6 +453,34 @@ let gDownloadObserver = {
         let dl = getDownload(id.data);
         removeFromView(dl);
         break;
+      case "private-browsing":
+        if (aData == "enter" || aData == "exit") {
+          // We need to reset the title here, because otherwise the title of
+          // the download manager would still reflect the progress of current
+          // active downloads, if any, after switching the private browsing
+          // mode, even though the downloads will no longer be accessible.
+          // If any download is auto-started after switching the private
+          // browsing mode, the title will be updated as needed by the progress
+          // listener.
+          document.title = document.documentElement.getAttribute("statictitle");
+
+          // We might get this notification before the download manager
+          // service, so the new database connection might not be ready
+          // yet.  Defer this until all private-browsing notifications
+          // have been processed.
+          setTimeout(function() {
+            initStatement();
+            buildDownloadList(true);
+          }, 0);
+        }
+        break;
+      case "browser-lastwindow-close-granted":
+//@line 535 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/mozapps/downloads/content/downloads.js"
+        if (gDownloadManager.activeDownloadCount == 0) {
+          setTimeout(gCloseDownloadManager, 0);
+        }
+//@line 539 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/mozapps/downloads/content/downloads.js"
+        break;
     }
   }
 };
@@ -614,29 +632,26 @@ function buildContextMenu(aEvent)
 
 var gDownloadDNDObserver =
 {
-  onDragOver: function (aEvent, aFlavour, aDragSession)
+  onDragOver: function (aEvent)
   {
-    aDragSession.canDrop = true;
+    var types = aEvent.dataTransfer.types;
+    if (types.contains("text/uri-list") ||
+        types.contains("text/x-moz-url") ||
+        types.contains("text/plain"))
+      aEvent.preventDefault();
   },
 
-  onDrop: function(aEvent, aXferData, aDragSession)
+  onDrop: function(aEvent)
   {
-    var split = aXferData.data.split("\n");
-    var url = split[0];
-    if (url != aXferData.data) {  //do nothing, not a valid URL
-      var name = split[1];
-      saveURL(url, name, null, true, true);
+    var dt = aEvent.dataTransfer;
+    var url = dt.getData("URL");
+    var name;
+    if (!url) {
+      url = dt.getData("text/x-moz-url") || dt.getData("text/plain");
+      [url, name] = url.split("\n");
     }
-  },
-  _flavourSet: null,
-  getSupportedFlavours: function ()
-  {
-    if (!this._flavourSet) {
-      this._flavourSet = new FlavourSet();
-      this._flavourSet.appendFlavour("text/x-moz-url");
-      this._flavourSet.appendFlavour("text/unicode");
-    }
-    return this._flavourSet;
+    if (url)
+      saveURL(url, name ? name : url, null, true, true);
   }
 }
 
@@ -1040,9 +1055,6 @@ function removeFromView(aDownload)
   gDownloadsView.removeChild(aDownload);
   gDownloadsView.selectedIndex = Math.min(index, gDownloadsView.itemCount - 1);
 
-  // Color everything after from the newly selected item
-  stripeifyList(gDownloadsView.selectedItem);
-
   // We might have removed the last item, so update the clear list button
   updateClearListButton();
 }
@@ -1158,9 +1170,8 @@ function stepListBuilder(aNumItems) {
     // Make the item and add it to the end if it's active or matches the search
     let item = createDownloadItem(attrs);
     if (item && (isActive || downloadMatchesSearch(item))) {
-      // Add item to the end and color just that one item
+      // Add item to the end
       gDownloadsView.appendChild(item);
-      stripeifyList(item);
     
       // Because of the joys of XBL, we can't update the buttons until the
       // download object is in the document.
@@ -1211,9 +1222,8 @@ function prependList(aDownload)
   // Make the item and add it to the beginning
   let item = createDownloadItem(attrs);
   if (item) {
-    // Add item to the beginning and color the whole list
+    // Add item to the beginning
     gDownloadsView.insertBefore(item, gDownloadsView.firstChild);
-    stripeifyList(item);
     
     // Because of the joys of XBL, we can't update the buttons until the
     // download object is in the document.
@@ -1243,33 +1253,12 @@ function downloadMatchesSearch(aItem)
 
   // Make sure each of the terms are found
   for each (let term in gSearchTerms)
-    if (combinedSearch.search(term) == -1)
+    if (combinedSearch.indexOf(term) == -1)
       return false;
 
   return true;
 }
 
-/**
- * Stripeify the download list by setting or clearing the "alternate" attribute
- * on items starting from a particular item and continuing to the end.
- *
- * @param aItem
- *        Download rishlist item to start stripeifying
- */
-function stripeifyList(aItem)
-{
-  let alt = "alternate";
-  // Set the item to be opposite of the other
-  let flipFrom = function(aOther) aOther && aOther.hasAttribute(alt) ?
-    aItem.removeAttribute(alt) : aItem.setAttribute(alt, "true");
-
-  // Keep coloring items as the opposite of its previous until no more
-  while (aItem) {
-    flipFrom(aItem.previousSibling);
-    aItem = aItem.nextSibling;
-  }
-}
-
 // we should be using real URLs all the time, but until
 // bug 239948 is fully fixed, this will do...
 //
@@ -1305,3 +1294,27 @@ function updateClearListButton()
   // The button is enabled if we have items in the list and we can clean up
   button.disabled = !(gDownloadsView.itemCount && gDownloadManager.canCleanUp);
 }
+
+function getDownload(aID)
+{
+  return document.getElementById("dl" + aID);
+}
+
+/**
+ * Initialize the statement which is used to retrieve the list of downloads.
+ *
+ * This function gets called both at startup, and when entering the private
+ * browsing mode (because the database connection is changed when entering
+ * the private browsing mode, and a new statement should be initialized.
+ */
+function initStatement()
+{
+  if (gStmt)
+    gStmt.finalize();
+
+  gStmt = gDownloadManager.DBConnection.createStatement(
+    "SELECT id, target, name, source, state, startTime, endTime, referrer, " +
+           "currBytes, maxBytes, state IN (?1, ?2, ?3, ?4, ?5) isActive " +
+    "FROM moz_downloads " +
+    "ORDER BY isActive DESC, endTime DESC, startTime DESC");
+}
