@@ -1,4 +1,4 @@
-//@line 43 "/usr/obj/i386/mozilla-firefox-3.0.18/mozilla/toolkit/components/passwordmgr/content/passwordManager.js"
+//@line 43 "/usr/obj/i386/mozilla-firefox-3.6.8/mozilla-1.9.2/toolkit/components/passwordmgr/content/passwordManager.js"
 
 /*** =================== SAVED SIGNONS CODE =================== ***/
 
@@ -8,21 +8,27 @@ function SignonsStartup() {
   kSignonBundle = document.getElementById("signonBundle");
   document.getElementById("togglePasswords").label = kSignonBundle.getString("showPasswords");
   document.getElementById("togglePasswords").accessKey = kSignonBundle.getString("showPasswordsAccessKey");
-  document.getElementById("signonsIntro").value = kSignonBundle.getString("loginsSpielAll");
+  document.getElementById("signonsIntro").textContent = kSignonBundle.getString("loginsSpielAll");
   LoadSignons();
 
   // filter the table if requested by caller
-  if (window.arguments && window.arguments[0] &&
+  if (window.arguments &&
+      window.arguments[0] &&
       window.arguments[0].filterString)
     setFilter(window.arguments[0].filterString);
 
   FocusFilterBox();
 }
 
+function setFilter(aFilterString) {
+  document.getElementById("filter").value = aFilterString;
+  _filterPasswords();
+}
+
 var signonsTreeView = {
   _filterSet : [],
   _lastSelectedRanges : [],
-  selection: null, 
+  selection: null,
 
   rowCount : 0,
   setTree : function(tree) {},
@@ -50,18 +56,29 @@ var signonsTreeView = {
   cycleHeader : function(column) {},
   getRowProperties : function(row,prop) {},
   getColumnProperties : function(column,prop) {},
-  getCellProperties : function(row,column,prop) {}
+  getCellProperties : function(row,column,prop) {
+    if (column.element.getAttribute("id") == "siteCol")
+      prop.AppendElement(kLTRAtom);
+  }
  };
 
 
 function LoadSignons() {
   // loads signons into table
-  signons = passwordmanager.getAllLogins({});
+  try {
+    signons = passwordmanager.getAllLogins({});
+  } catch (e) {
+    signons = [];
+  }
   signonsTreeView.rowCount = signons.length;
 
   // sort and display the table
   signonsTree.treeBoxObject.view = signonsTreeView;
-  SignonColumnSort('hostname');
+  // The sort column didn't change. SortTree (called by
+  // SignonColumnSort) assumes we want to toggle the sort
+  // direction but here we don't so we have to trick it
+  lastSignonSortAscending = !lastSignonSortAscending;
+  SignonColumnSort(lastSignonSortColumn);
 
   // disable "remove all signons" button if there are no signons
   var element = document.getElementById("removeAllSignons");
@@ -73,7 +90,7 @@ function LoadSignons() {
     element.removeAttribute("disabled");
     toggle.removeAttribute("disabled");
   }
- 
+
   return true;
 }
 
@@ -113,14 +130,19 @@ function DeleteAllSignons() {
 }
 
 function TogglePasswordVisible() {
-  if (!showingPasswords && !ConfirmShowPasswords())
-    return;
+  if (showingPasswords || ConfirmShowPasswords()) {
+    showingPasswords = !showingPasswords;
+    document.getElementById("togglePasswords").label = kSignonBundle.getString(showingPasswords ? "hidePasswords" : "showPasswords");
+    document.getElementById("togglePasswords").accessKey = kSignonBundle.getString(showingPasswords ? "hidePasswordsAccessKey" : "showPasswordsAccessKey");
+    document.getElementById("passwordCol").hidden = !showingPasswords;
+    _filterPasswords();
+  }
 
-  showingPasswords = !showingPasswords;
-  document.getElementById("togglePasswords").label = kSignonBundle.getString(showingPasswords ? "hidePasswords" : "showPasswords");
-  document.getElementById("togglePasswords").accessKey = kSignonBundle.getString(showingPasswords ? "hidePasswordsAccessKey" : "showPasswordsAccessKey");
-  document.getElementById("passwordCol").hidden = !showingPasswords;
-  _filterPasswords();
+  // Notify observers that the password visibility toggling is
+  // completed.  (Mostly useful for tests)
+  Components.classes["@mozilla.org/observer-service;1"]
+            .getService(Components.interfaces.nsIObserverService)
+            .notifyObservers(null, "passwordmgr-password-toggle-complete", null);
 }
 
 function AskUserShowPasswords() {
@@ -163,8 +185,13 @@ function FinalizeSignonDeletions(syncNeeded) {
   }
   // If the deletion has been performed in a filtered view, reflect the deletion in the unfiltered table.
   // See bug 405389.
-  if (syncNeeded)
-    signons = passwordmanager.getAllLogins({});
+  if (syncNeeded) {
+    try {
+      signons = passwordmanager.getAllLogins({});
+    } catch (e) {
+      signons = [];
+    }
+  }
   deletedSignons.length = 0;
 }
 
@@ -174,35 +201,54 @@ function HandleSignonKeyPress(e) {
   }
 }
 
-var lastSignonSortColumn = "";
-var lastSignonSortAscending = false;
+function getColumnByName(column) {
+  switch (column) {
+    case "hostname":
+      return document.getElementById("siteCol");
+    case "username":
+      return document.getElementById("userCol");
+    case "password":
+      return document.getElementById("passwordCol");
+  }
+}
+
+var lastSignonSortColumn = "hostname";
+var lastSignonSortAscending = true;
 
 function SignonColumnSort(column) {
+  // clear out the sortDirection attribute on the old column
+  var lastSortedCol = getColumnByName(lastSignonSortColumn);
+  lastSortedCol.removeAttribute("sortDirection");
+
+  // sort
   lastSignonSortAscending =
     SortTree(signonsTree, signonsTreeView,
                  signonsTreeView._filterSet.length ? signonsTreeView._filterSet : signons,
                  column, lastSignonSortColumn, lastSignonSortAscending);
   lastSignonSortColumn = column;
+
+  // set the sortDirection attribute to get the styling going
+  // first we need to get the right element
+  var sortedCol = getColumnByName(column);
+  sortedCol.setAttribute("sortDirection", lastSignonSortAscending ?
+                                          "ascending" : "descending");
 }
 
 function SignonClearFilter() {
   var singleSelection = (signonsTreeView.selection.count == 1);
 
-  // Clear the Filter and the Tree Display
-  document.getElementById("filter").value = "";
+  // Clear the Tree Display
   signonsTreeView.rowCount = 0;
   signonsTree.treeBoxObject.rowCountChanged(0, -signonsTreeView._filterSet.length);
   signonsTreeView._filterSet = [];
 
   // Just reload the list to make sure deletions are respected
-  lastSignonSortColumn = "";
-  lastSignonSortAscending = false;
   LoadSignons();
-    
+
   // Restore selection
   if (singleSelection) {
     signonsTreeView.selection.clearSelection();
-    for (i = 0; i < signonsTreeView._lastSelectedRanges.length; ++i) {
+    for (let i = 0; i < signonsTreeView._lastSelectedRanges.length; ++i) {
       var range = signonsTreeView._lastSelectedRanges[i];
       signonsTreeView.selection.rangedSelect(range.min, range.max, true);
     }
@@ -211,15 +257,13 @@ function SignonClearFilter() {
   }
   signonsTreeView._lastSelectedRanges = [];
 
-  document.getElementById("signonsIntro").value = kSignonBundle.getString("loginsSpielAll");
-  document.getElementById("clearFilter").disabled = true;
-  FocusFilterBox();
+  document.getElementById("signonsIntro").textContent = kSignonBundle.getString("loginsSpielAll");
 }
 
-function FocusFilterBox()
-{
-  if (document.getElementById("filter").getAttribute("focused") != "true")
-    document.getElementById("filter").focus();
+function FocusFilterBox() {
+  var filterBox = document.getElementById("filter");
+  if (filterBox.getAttribute("focused") != "true")
+    filterBox.focus();
 }
 
 function SignonMatchesFilter(aSignon, aFilterValue) {
@@ -266,13 +310,15 @@ function _filterPasswords()
   var newFilterSet = FilterPasswords(filter, signonsTreeView);
   if (!signonsTreeView._filterSet.length) {
     // Save Display Info for the Non-Filtered mode when we first
-    // enter Filtered mode. 
+    // enter Filtered mode.
     SignonSaveState();
   }
   signonsTreeView._filterSet = newFilterSet;
 
   // Clear the display
-  signonsTree.treeBoxObject.rowCountChanged(0, -signonsTreeView.rowCount);
+  let oldRowCount = signonsTreeView.rowCount;
+  signonsTreeView.rowCount = 0;
+  signonsTree.treeBoxObject.rowCountChanged(0, -oldRowCount);
   // Set up the filtered display
   signonsTreeView.rowCount = signonsTreeView._filterSet.length;
   signonsTree.treeBoxObject.rowCountChanged(0, signonsTreeView.rowCount);
@@ -281,19 +327,5 @@ function _filterPasswords()
   if (signonsTreeView.rowCount > 0)
     signonsTreeView.selection.select(0);
 
-  document.getElementById("signonsIntro").value = kSignonBundle.getString("loginsSpielFiltered");
-  document.getElementById("clearFilter").disabled = false;
-}
-
-function HandleSignonFilterKeyPress(aEvent) {
-  if (aEvent.keyCode == KeyEvent.DOM_VK_ESCAPE &&
-      document.getElementById("filter").value != "")
-    SignonClearFilter();
-}
-
-function setFilter(aFilterString) {
-  if (document.getElementById("filter").value != "")
-    SignonClearFilter();
-  document.getElementById("filter").value = aFilterString;
-  _filterPasswords();
+  document.getElementById("signonsIntro").textContent = kSignonBundle.getString("loginsSpielFiltered");
 }
